@@ -1,6 +1,6 @@
 DS <- function(abund.formula, det.formula, data, inits, priors, tuning,
                n.batch, batch.length, accept.rate = 0.43, family = 'Poisson',
-	       transect = 'line', det.func = 'halfnormal',
+               transect = 'line', det.func = 'halfnormal',
                n.omp.threads = 1, verbose = TRUE,
                n.report = 100, n.burn = round(.10 * n.batch * batch.length), n.thin = 1,
                n.chains = 1, ...){
@@ -108,6 +108,10 @@ DS <- function(abund.formula, det.formula, data, inits, priors, tuning,
   if (n.thin > n.samples) {
     stop("error: n.thin must be less than n.samples")
   }
+  # Check if n.burn, n.thin, and n.samples result in an integer and error if otherwise.
+  if (((n.samples - n.burn) / n.thin) %% 1 != 0) {
+    stop("the number of posterior samples to save ((n.samples - n.burn) / n.thin) is not a whole number. Please respecify the MCMC criteria such that the number of posterior samples saved is a whole number.")
+  }
 
   if (!(family) %in% c('Poisson', 'NB')) {
     stop("family must be either 'Poisson' or 'NB'")
@@ -533,7 +537,7 @@ DS <- function(abund.formula, det.formula, data, inits, priors, tuning,
       }
     }
     beta.star.indx <- rep(0:(p.abund.re - 1), n.abund.re.long)
-    beta.star.inits <- rnorm(n.abund.re, sqrt(sigma.sq.mu.inits[beta.star.indx + 1]))
+    beta.star.inits <- rnorm(n.abund.re, 0, sqrt(sigma.sq.mu.inits[beta.star.indx + 1]))
   } else {
     sigma.sq.mu.inits <- 0
     beta.star.indx <- 0
@@ -773,7 +777,7 @@ DS <- function(abund.formula, det.formula, data, inits, priors, tuning,
       alpha.inits <- runif(p.det, -10, 10)
       if (p.abund.re > 0) {
         sigma.sq.mu.inits <- runif(p.abund.re, 0.05, 1)
-        beta.star.inits <- rnorm(n.abund.re, sqrt(sigma.sq.mu.inits[beta.star.indx + 1]))
+        beta.star.inits <- rnorm(n.abund.re, 0, sqrt(sigma.sq.mu.inits[beta.star.indx + 1]))
       }
       if (p.det.re > 0) {
         sigma.sq.p.inits <- runif(p.det.re, 0.05, 0.5)
