@@ -192,6 +192,10 @@ sfMsAbundGaussian <- function(formula, data, inits, priors,
   if (n.thin > n.samples) {
     stop("error: n.thin must be less than n.samples")
   }
+  # Check if n.burn, n.thin, and n.samples result in an integer and error if otherwise.
+  if (((n.samples - n.burn) / n.thin) %% 1 != 0) {
+    stop("the number of posterior samples to save ((n.samples - n.burn) / n.thin) is not a whole number. Please respecify the MCMC criteria such that the number of posterior samples saved is a whole number.")
+  }
 
   # y is ordered by site, then species within site.
   y.orig <- y
@@ -636,7 +640,7 @@ sfMsAbundGaussian <- function(formula, data, inits, priors,
       }
     }
     beta.star.indx <- rep(0:(p.re - 1), n.re.long)
-    beta.star.inits <- rnorm(n.re, sqrt(sigma.sq.mu.inits[beta.star.indx + 1]))
+    beta.star.inits <- rnorm(n.re, 0, sqrt(sigma.sq.mu.inits[beta.star.indx + 1]))
     beta.star.inits <- rep(beta.star.inits, N)
   } else {
     sigma.sq.mu.inits <- 0
@@ -849,7 +853,7 @@ sfMsAbundGaussian <- function(formula, data, inits, priors,
         }
         if (p.re > 0) {
           sigma.sq.mu.inits <- runif(p.re, 0.5, 10)
-          beta.star.inits <- rnorm(n.re, sqrt(sigma.sq.mu.inits[beta.star.indx + 1]))
+          beta.star.inits <- rnorm(n.re, 0, sqrt(sigma.sq.mu.inits[beta.star.indx + 1]))
           beta.star.inits <- rep(beta.star.inits, N)
         }
       }
