@@ -105,6 +105,10 @@ sfMsNMix <- function(abund.formula, det.formula, data, inits, priors,
   if (n.thin > n.samples) {
     stop("n.thin must be less than n.samples")
   }
+  # Check if n.burn, n.thin, and n.samples result in an integer and error if otherwise.
+  if (((n.samples - n.burn) / n.thin) %% 1 != 0) {
+    stop("the number of posterior samples to save ((n.samples - n.burn) / n.thin) is not a whole number. Please respecify the MCMC criteria such that the number of posterior samples saved is a whole number.")
+  }
   if (missing(n.factors)) {
     stop("n.factors must be specified for a spatial factor N-mixture model")
   }
@@ -862,7 +866,7 @@ sfMsNMix <- function(abund.formula, det.formula, data, inits, priors,
       }
     }
     beta.star.indx <- rep(0:(p.abund.re - 1), n.abund.re.long)
-    beta.star.inits <- rnorm(n.abund.re, sqrt(sigma.sq.mu.inits[beta.star.indx + 1]))
+    beta.star.inits <- rnorm(n.abund.re, 0, sqrt(sigma.sq.mu.inits[beta.star.indx + 1]))
     # Starting values for all species
     beta.star.inits <- rep(beta.star.inits, n.sp)
   } else {
@@ -893,7 +897,7 @@ sfMsNMix <- function(abund.formula, det.formula, data, inits, priors,
       }
     }
     alpha.star.indx <- rep(0:(p.det.re - 1), n.det.re.long)
-    alpha.star.inits <- rnorm(n.det.re, sqrt(sigma.sq.p.inits[alpha.star.indx + 1]))
+    alpha.star.inits <- rnorm(n.det.re, 0, sqrt(sigma.sq.p.inits[alpha.star.indx + 1]))
     alpha.star.inits <- rep(alpha.star.inits, n.sp)
   } else {
     sigma.sq.p.inits <- 0
@@ -1345,12 +1349,12 @@ sfMsNMix <- function(abund.formula, det.formula, data, inits, priors,
         }
         if (p.abund.re > 0) {
           sigma.sq.mu.inits <- runif(p.abund.re, 0.05, 1)
-          beta.star.inits <- rnorm(n.abund.re, sqrt(sigma.sq.mu.inits[beta.star.indx + 1]))
+          beta.star.inits <- rnorm(n.abund.re, 0, sqrt(sigma.sq.mu.inits[beta.star.indx + 1]))
           beta.star.inits <- rep(beta.star.inits, n.sp)
         }
         if (p.det.re > 0) {
           sigma.sq.p.inits <- runif(p.det.re, 0.05, 1)
-          alpha.star.inits <- rnorm(n.det.re, sqrt(sigma.sq.p.inits[alpha.star.indx + 1]))
+          alpha.star.inits <- rnorm(n.det.re, 0, sqrt(sigma.sq.p.inits[alpha.star.indx + 1]))
           alpha.star.inits <- rep(alpha.star.inits, n.sp)
         }
       }
