@@ -113,6 +113,10 @@ spAbund <- function(formula, data, inits, priors, tuning,
     if (n.thin > n.samples) {
       stop("error: n.thin must be less than n.samples")
     }
+    # Check if n.burn, n.thin, and n.samples result in an integer and error if otherwise.
+    if (((n.samples - n.burn) / n.thin) %% 1 != 0) {
+      stop("the number of posterior samples to save ((n.samples - n.burn) / n.thin) is not a whole number. Please respecify the MCMC criteria such that the number of posterior samples saved is a whole number.")
+    }
 
     if (!(family) %in% c('Poisson', 'NB')) {
       stop("family must be either 'Poisson' or 'NB'")
@@ -487,7 +491,7 @@ spAbund <- function(formula, data, inits, priors, tuning,
         }
       }
       beta.star.indx <- rep(0:(p.abund.re - 1), n.abund.re.long)
-      beta.star.inits <- rnorm(n.abund.re, sqrt(sigma.sq.mu.inits[beta.star.indx + 1]))
+      beta.star.inits <- rnorm(n.abund.re, 0, sqrt(sigma.sq.mu.inits[beta.star.indx + 1]))
     } else {
       sigma.sq.mu.inits <- 0
       beta.star.indx <- 0
@@ -833,7 +837,7 @@ spAbund <- function(formula, data, inits, priors, tuning,
           beta.inits <- rnorm(p.abund, 0, 1)
           if (p.abund.re > 0) {
             sigma.sq.mu.inits <- runif(p.abund.re, 0.05, 1)
-            beta.star.inits <- rnorm(n.abund.re, sqrt(sigma.sq.mu.inits[beta.star.indx + 1]))
+            beta.star.inits <- rnorm(n.abund.re, 0, sqrt(sigma.sq.mu.inits[beta.star.indx + 1]))
           }
           if (family == 'NB') {
             kappa.inits <- runif(1, kappa.a, kappa.b)
