@@ -1,10 +1,10 @@
 spAbundGaussian <- function(formula, data, inits, priors, tuning,
-                    cov.model = 'exponential', NNGP = TRUE,
-		    n.neighbors = 15,  search.type = 'cb', n.batch,
-		    batch.length, accept.rate = 0.43, family = 'Gaussian',
-		    n.omp.threads = 1, verbose = TRUE, n.report = 100,
-		    n.burn = round(.10 * n.batch * batch.length),
-		    n.thin = 1, n.chains = 1, save.fitted = TRUE, ...){
+                            cov.model = 'exponential', NNGP = TRUE,
+                            n.neighbors = 15,  search.type = 'cb', n.batch,
+                            batch.length, accept.rate = 0.43, family = 'Gaussian',
+                            n.omp.threads = 1, verbose = TRUE, n.report = 100,
+                            n.burn = round(.10 * n.batch * batch.length),
+                            n.thin = 1, n.chains = 1, save.fitted = TRUE, ...){
 
   ptm <- proc.time()
 
@@ -203,6 +203,10 @@ spAbundGaussian <- function(formula, data, inits, priors, tuning,
   if (n.thin > n.samples) {
     stop("error: n.thin must be less than n.samples")
   }
+  # Check if n.burn, n.thin, and n.samples result in an integer and error if otherwise.
+  if (((n.samples - n.burn) / n.thin) %% 1 != 0) {
+    stop("the number of posterior samples to save ((n.samples - n.burn) / n.thin) is not a whole number. Please respecify the MCMC criteria such that the number of posterior samples saved is a whole number.")
+  }
   n.post.samples <- length(seq(from = n.burn + 1,
                                to = n.samples,
                                by = as.integer(n.thin)))
@@ -500,7 +504,7 @@ spAbundGaussian <- function(formula, data, inits, priors, tuning,
       }
     }
     beta.star.indx <- rep(0:(p.re - 1), n.re.long)
-    beta.star.inits <- rnorm(n.re, sqrt(sigma.sq.mu.inits[beta.star.indx + 1]))
+    beta.star.inits <- rnorm(n.re, 0, sqrt(sigma.sq.mu.inits[beta.star.indx + 1]))
   } else {
     sigma.sq.mu.inits <- 0
     beta.star.indx <- 0
@@ -720,7 +724,7 @@ spAbundGaussian <- function(formula, data, inits, priors, tuning,
         }
         if (p.re > 0) {
           sigma.sq.mu.inits <- runif(p.re, 0.5, 10)
-          beta.star.inits <- rnorm(n.re, sqrt(sigma.sq.mu.inits[beta.star.indx + 1]))
+          beta.star.inits <- rnorm(n.re, 0, sqrt(sigma.sq.mu.inits[beta.star.indx + 1]))
         }
         tau.sq.inits <- runif(1, 0.1, 10)
       }
