@@ -1,10 +1,10 @@
 spNMix <- function(abund.formula, det.formula, data, inits, priors, tuning,
-		   cov.model = 'exponential', NNGP = TRUE,
-		   n.neighbors = 15, search.type = 'cb',
-		   n.batch, batch.length, accept.rate = 0.43, family = 'Poisson',
-		   n.omp.threads = 1, verbose = TRUE,
-		   n.report = 100, n.burn = round(.10 * n.batch * batch.length), n.thin = 1,
-		   n.chains = 1, ...){
+                   cov.model = 'exponential', NNGP = TRUE,
+                   n.neighbors = 15, search.type = 'cb',
+                   n.batch, batch.length, accept.rate = 0.43, family = 'Poisson',
+                   n.omp.threads = 1, verbose = TRUE,
+                   n.report = 100, n.burn = round(.10 * n.batch * batch.length), n.thin = 1,
+                   n.chains = 1, ...){
 
   ptm <- proc.time()
 
@@ -113,6 +113,10 @@ spNMix <- function(abund.formula, det.formula, data, inits, priors, tuning,
   if (n.thin > n.samples) {
     stop("error: n.thin must be less than n.samples")
   }
+  # Check if n.burn, n.thin, and n.samples result in an integer and error if otherwise.
+  if (((n.samples - n.burn) / n.thin) %% 1 != 0) {
+    stop("the number of posterior samples to save ((n.samples - n.burn) / n.thin) is not a whole number. Please respecify the MCMC criteria such that the number of posterior samples saved is a whole number.")
+  }
 
   if (!(family) %in% c('Poisson', 'NB')) {
     stop("family must be either 'Poisson' or 'NB'")
@@ -665,7 +669,7 @@ spNMix <- function(abund.formula, det.formula, data, inits, priors, tuning,
       }
     }
     beta.star.indx <- rep(0:(p.abund.re - 1), n.abund.re.long)
-    beta.star.inits <- rnorm(n.abund.re, sqrt(sigma.sq.mu.inits[beta.star.indx + 1]))
+    beta.star.inits <- rnorm(n.abund.re, 0, sqrt(sigma.sq.mu.inits[beta.star.indx + 1]))
   } else {
     sigma.sq.mu.inits <- 0
     beta.star.indx <- 0
@@ -695,7 +699,7 @@ spNMix <- function(abund.formula, det.formula, data, inits, priors, tuning,
       }
     }
     alpha.star.indx <- rep(0:(p.det.re - 1), n.det.re.long)
-    alpha.star.inits <- rnorm(n.det.re, sqrt(sigma.sq.p.inits[alpha.star.indx + 1]))
+    alpha.star.inits <- rnorm(n.det.re, 0, sqrt(sigma.sq.p.inits[alpha.star.indx + 1]))
   } else {
     sigma.sq.p.inits <- 0
     alpha.star.indx <- 0
@@ -1101,11 +1105,11 @@ spNMix <- function(abund.formula, det.formula, data, inits, priors, tuning,
         alpha.inits <- rnorm(p.det, 0, 1)
         if (p.abund.re > 0) {
           sigma.sq.mu.inits <- runif(p.abund.re, 0.05, 2)
-          beta.star.inits <- rnorm(n.abund.re, sqrt(sigma.sq.mu.inits[beta.star.indx + 1]))
+          beta.star.inits <- rnorm(n.abund.re, 0, sqrt(sigma.sq.mu.inits[beta.star.indx + 1]))
         }
         if (p.det.re > 0) {
           sigma.sq.p.inits <- runif(p.det.re, 0.5, 2)
-          alpha.star.inits <- rnorm(n.det.re, sqrt(sigma.sq.p.inits[alpha.star.indx + 1]))
+          alpha.star.inits <- rnorm(n.det.re, 0, sqrt(sigma.sq.p.inits[alpha.star.indx + 1]))
         }
         kappa.inits <- runif(1, kappa.a, kappa.b)
         if (!sigma.sq.ig) {
