@@ -7,6 +7,7 @@
 #include <omp.h>
 #endif
 
+#define R_NO_REMAP
 #include <R.h>
 #include <Rmath.h>
 #include <Rinternals.h>
@@ -18,30 +19,30 @@
 #endif
 
 extern "C" {
-  SEXP DS(SEXP y_r, SEXP X_r, SEXP Xp_r, SEXP XRE_r, SEXP XpRE_r, 
+  SEXP DS(SEXP y_r, SEXP X_r, SEXP Xp_r, SEXP XRE_r, SEXP XpRE_r,
           SEXP XRandom_r, SEXP XpRandom_r, SEXP yMax_r, SEXP offset_r,
           SEXP consts_r, SEXP K_r, SEXP nAbundRELong_r, SEXP nDetRELong_r,
           SEXP betaStarting_r, SEXP alphaStarting_r, SEXP kappaStarting_r,
           SEXP sigmaSqMuStarting_r, SEXP sigmaSqPStarting_r,
           SEXP betaStarStarting_r, SEXP alphaStarStarting_r, SEXP NStarting_r,
-          SEXP NLongIndx_r, SEXP betaStarIndx_r, SEXP betaLevelIndx_r, 
+          SEXP NLongIndx_r, SEXP betaStarIndx_r, SEXP betaLevelIndx_r,
           SEXP alphaStarIndx_r, SEXP alphaLevelIndx_r,
-          SEXP muBeta_r, SEXP SigmaBeta_r, 
-          SEXP muAlpha_r, SEXP SigmaAlpha_r, 
-          SEXP sigmaSqMuA_r, SEXP sigmaSqMuB_r, 
-          SEXP sigmaSqPA_r, SEXP sigmaSqPB_r, 
-          SEXP kappaA_r, SEXP kappaB_r, SEXP detModel_r, 
-	  SEXP transect_r, SEXP distBreaks_r, SEXP tuning_r,
-          SEXP nBatch_r, SEXP batchLength_r, SEXP acceptRate_r, SEXP nThreads_r, 
+          SEXP muBeta_r, SEXP SigmaBeta_r,
+          SEXP muAlpha_r, SEXP SigmaAlpha_r,
+          SEXP sigmaSqMuA_r, SEXP sigmaSqMuB_r,
+          SEXP sigmaSqPA_r, SEXP sigmaSqPB_r,
+          SEXP kappaA_r, SEXP kappaB_r, SEXP detModel_r,
+          SEXP transect_r, SEXP distBreaks_r, SEXP tuning_r,
+          SEXP nBatch_r, SEXP batchLength_r, SEXP acceptRate_r, SEXP nThreads_r,
           SEXP verbose_r, SEXP nReport_r, SEXP samplesInfo_r,
           SEXP chainInfo_r, SEXP family_r){
-   
+
     /**********************************************************************
      * Initial constants
      * *******************************************************************/
     int i, g, t, j, s, l, k, ll, nProtect=0;
     const int inc = 1;
-    
+
     /**********************************************************************
      * Get Inputs
      * *******************************************************************/
@@ -50,7 +51,7 @@ extern "C" {
     double *Xp = REAL(Xp_r);
     double *yMax = REAL(yMax_r);
     double *offset = REAL(offset_r);
-    int *XRE = INTEGER(XRE_r); 
+    int *XRE = INTEGER(XRE_r);
     int *XpRE = INTEGER(XpRE_r);
     double *XRandom = REAL(XRandom_r);
     double *XpRandom = REAL(XpRandom_r);
@@ -64,34 +65,34 @@ extern "C" {
     int pDetRE = INTEGER(consts_r)[6];
     int nDetRE = INTEGER(consts_r)[7];
     int ppDet = pDet * pDet;
-    int ppAbund = pAbund * pAbund; 
-    double *muBeta = (double *) R_alloc(pAbund, sizeof(double));   
+    int ppAbund = pAbund * pAbund;
+    double *muBeta = (double *) R_alloc(pAbund, sizeof(double));
     F77_NAME(dcopy)(&pAbund, REAL(muBeta_r), &inc, muBeta, &inc);
-    double *muAlpha = (double *) R_alloc(pDet, sizeof(double));   
+    double *muAlpha = (double *) R_alloc(pDet, sizeof(double));
     F77_NAME(dcopy)(&pDet, REAL(muAlpha_r), &inc, muAlpha, &inc);
-    double *SigmaBeta = (double *) R_alloc(ppAbund, sizeof(double));   
+    double *SigmaBeta = (double *) R_alloc(ppAbund, sizeof(double));
     F77_NAME(dcopy)(&ppAbund, REAL(SigmaBeta_r), &inc, SigmaBeta, &inc);
-    double *SigmaAlpha = (double *) R_alloc(ppDet, sizeof(double));   
+    double *SigmaAlpha = (double *) R_alloc(ppDet, sizeof(double));
     F77_NAME(dcopy)(&ppDet, REAL(SigmaAlpha_r), &inc, SigmaAlpha, &inc);
-    double *sigmaSqMuA = REAL(sigmaSqMuA_r); 
-    double *sigmaSqMuB = REAL(sigmaSqMuB_r); 
-    double *sigmaSqPA = REAL(sigmaSqPA_r); 
-    double *sigmaSqPB = REAL(sigmaSqPB_r); 
+    double *sigmaSqMuA = REAL(sigmaSqMuA_r);
+    double *sigmaSqMuB = REAL(sigmaSqMuB_r);
+    double *sigmaSqPA = REAL(sigmaSqPA_r);
+    double *sigmaSqPB = REAL(sigmaSqPB_r);
     double kappaA = REAL(kappaA_r)[0];
     double kappaB = REAL(kappaB_r)[0];
-    int *nAbundRELong = INTEGER(nAbundRELong_r); 
-    int *nDetRELong = INTEGER(nDetRELong_r); 
-    int K = INTEGER(K_r)[0]; 
-    int *alphaStarIndx = INTEGER(alphaStarIndx_r); 
+    int *nAbundRELong = INTEGER(nAbundRELong_r);
+    int *nDetRELong = INTEGER(nDetRELong_r);
+    int K = INTEGER(K_r)[0];
+    int *alphaStarIndx = INTEGER(alphaStarIndx_r);
     int *alphaLevelIndx = INTEGER(alphaLevelIndx_r);
-    int *betaStarIndx = INTEGER(betaStarIndx_r); 
+    int *betaStarIndx = INTEGER(betaStarIndx_r);
     int *betaLevelIndx = INTEGER(betaLevelIndx_r);
-    int nBatch = INTEGER(nBatch_r)[0]; 
-    int batchLength = INTEGER(batchLength_r)[0]; 
-    int nSamples = nBatch * batchLength; 
-    int nBurn = INTEGER(samplesInfo_r)[0]; 
+    int nBatch = INTEGER(nBatch_r)[0];
+    int batchLength = INTEGER(batchLength_r)[0];
+    int nSamples = nBatch * batchLength;
+    int nBurn = INTEGER(samplesInfo_r)[0];
     int nThin = INTEGER(samplesInfo_r)[1];
-    int nPost = INTEGER(samplesInfo_r)[2]; 
+    int nPost = INTEGER(samplesInfo_r)[2];
     int currChain = INTEGER(chainInfo_r)[0];
     double acceptRate = REAL(acceptRate_r)[0];
     double *tuning = REAL(tuning_r);
@@ -99,9 +100,9 @@ extern "C" {
     int nThreads = INTEGER(nThreads_r)[0];
     int verbose = INTEGER(verbose_r)[0];
     int nReport = INTEGER(nReport_r)[0];
-    int status = 0; 
+    int status = 0;
     int thinIndx = 0;
-    int sPost = 0;  
+    int sPost = 0;
     // NB = 1, Poisson = 0;
     int family = INTEGER(family_r)[0];
     // DS stuff
@@ -113,13 +114,13 @@ extern "C" {
     omp_set_num_threads(nThreads);
 #else
     if(nThreads > 1){
-      warning("n.omp.threads > 1, but source not compiled with OpenMP support.");
+      Rf_warning("n.omp.threads > 1, but source not compiled with OpenMP support.");
       nThreads = 1;
     }
 #endif
-    
+
     /**********************************************************************
-     * Print Information 
+     * Print Information
      * *******************************************************************/
     if(verbose){
       if (currChain == 1) {
@@ -132,10 +133,10 @@ extern "C" {
           Rprintf("Poisson HDS model with %i sites.\n\n", J);
 	}
         Rprintf("Samples per Chain: %i (%i batches of length %i)\n", nSamples, nBatch, batchLength);
-        Rprintf("Burn-in: %i \n", nBurn); 
-        Rprintf("Thinning Rate: %i \n", nThin); 
+        Rprintf("Burn-in: %i \n", nBurn);
+        Rprintf("Thinning Rate: %i \n", nThin);
         Rprintf("Number of Chains: %i \n", nChain);
-        Rprintf("Total Posterior Samples: %i \n\n", nPost * nChain); 
+        Rprintf("Total Posterior Samples: %i \n\n", nPost * nChain);
 #ifdef _OPENMP
         Rprintf("Source compiled with OpenMP support and model fit using %i thread(s).\n\n", nThreads);
 #else
@@ -155,90 +156,90 @@ extern "C" {
     /**********************************************************************
      * Parameters
      * *******************************************************************/
-    // Abundance Covariates 
-    double *beta = (double *) R_alloc(pAbund, sizeof(double));   
+    // Abundance Covariates
+    double *beta = (double *) R_alloc(pAbund, sizeof(double));
     F77_NAME(dcopy)(&pAbund, REAL(betaStarting_r), &inc, beta, &inc);
     // Abundance random effect variances
-    double *sigmaSqMu = (double *) R_alloc(pAbundRE, sizeof(double)); 
-    F77_NAME(dcopy)(&pAbundRE, REAL(sigmaSqMuStarting_r), &inc, sigmaSqMu, &inc); 
+    double *sigmaSqMu = (double *) R_alloc(pAbundRE, sizeof(double));
+    F77_NAME(dcopy)(&pAbundRE, REAL(sigmaSqMuStarting_r), &inc, sigmaSqMu, &inc);
     // Latent random effects
-    double *betaStar = (double *) R_alloc(nAbundRE, sizeof(double)); 
-    F77_NAME(dcopy)(&nAbundRE, REAL(betaStarStarting_r), &inc, betaStar, &inc); 
+    double *betaStar = (double *) R_alloc(nAbundRE, sizeof(double));
+    F77_NAME(dcopy)(&nAbundRE, REAL(betaStarStarting_r), &inc, betaStar, &inc);
     // Detection covariates
-    double *alpha = (double *) R_alloc(pDet, sizeof(double));   
+    double *alpha = (double *) R_alloc(pDet, sizeof(double));
     F77_NAME(dcopy)(&pDet, REAL(alphaStarting_r), &inc, alpha, &inc);
     // Detection random effect variances
-    double *sigmaSqP = (double *) R_alloc(pDetRE, sizeof(double)); 
-    F77_NAME(dcopy)(&pDetRE, REAL(sigmaSqPStarting_r), &inc, sigmaSqP, &inc); 
+    double *sigmaSqP = (double *) R_alloc(pDetRE, sizeof(double));
+    F77_NAME(dcopy)(&pDetRE, REAL(sigmaSqPStarting_r), &inc, sigmaSqP, &inc);
     // Latent detection random effects
-    double *alphaStar = (double *) R_alloc(nDetRE, sizeof(double)); 
-    F77_NAME(dcopy)(&nDetRE, REAL(alphaStarStarting_r), &inc, alphaStar, &inc); 
+    double *alphaStar = (double *) R_alloc(nDetRE, sizeof(double));
+    F77_NAME(dcopy)(&nDetRE, REAL(alphaStarStarting_r), &inc, alphaStar, &inc);
     // Size parameter
     double kappa = REAL(kappaStarting_r)[0];
     // Latent Abundance
-    double *N = (double *) R_alloc(J, sizeof(double));   
+    double *N = (double *) R_alloc(J, sizeof(double));
     F77_NAME(dcopy)(&J, REAL(NStarting_r), &inc, N, &inc);
 
     /**********************************************************************
      * Return Stuff
      * *******************************************************************/
     SEXP betaSamples_r;
-    PROTECT(betaSamples_r = allocMatrix(REALSXP, pAbund, nPost)); nProtect++;
+    PROTECT(betaSamples_r = Rf_allocMatrix(REALSXP, pAbund, nPost)); nProtect++;
     zeros(REAL(betaSamples_r), pAbund * nPost);
-    SEXP alphaSamples_r; 
-    PROTECT(alphaSamples_r = allocMatrix(REALSXP, pDet, nPost)); nProtect++;
+    SEXP alphaSamples_r;
+    PROTECT(alphaSamples_r = Rf_allocMatrix(REALSXP, pDet, nPost)); nProtect++;
     zeros(REAL(alphaSamples_r), pDet * nPost);
-    SEXP NSamples_r; 
-    PROTECT(NSamples_r = allocMatrix(REALSXP, J, nPost)); nProtect++; 
+    SEXP NSamples_r;
+    PROTECT(NSamples_r = Rf_allocMatrix(REALSXP, J, nPost)); nProtect++;
     zeros(REAL(NSamples_r), J * nPost);
     SEXP kappaSamples_r;
     if (family == 1) {
-      PROTECT(kappaSamples_r = allocMatrix(REALSXP, inc, nPost)); nProtect++;
+      PROTECT(kappaSamples_r = Rf_allocMatrix(REALSXP, inc, nPost)); nProtect++;
       zeros(REAL(kappaSamples_r), nPost);
     }
-    SEXP muSamples_r; 
-    PROTECT(muSamples_r = allocMatrix(REALSXP, J, nPost)); nProtect++; 
+    SEXP muSamples_r;
+    PROTECT(muSamples_r = Rf_allocMatrix(REALSXP, J, nPost)); nProtect++;
     zeros(REAL(muSamples_r), J * nPost);
     // Detection random effects
-    SEXP sigmaSqPSamples_r; 
-    SEXP alphaStarSamples_r; 
+    SEXP sigmaSqPSamples_r;
+    SEXP alphaStarSamples_r;
     if (pDetRE > 0) {
-      PROTECT(sigmaSqPSamples_r = allocMatrix(REALSXP, pDetRE, nPost)); nProtect++;
+      PROTECT(sigmaSqPSamples_r = Rf_allocMatrix(REALSXP, pDetRE, nPost)); nProtect++;
       zeros(REAL(sigmaSqPSamples_r), pDetRE * nPost);
-      PROTECT(alphaStarSamples_r = allocMatrix(REALSXP, nDetRE, nPost)); nProtect++;
+      PROTECT(alphaStarSamples_r = Rf_allocMatrix(REALSXP, nDetRE, nPost)); nProtect++;
       zeros(REAL(alphaStarSamples_r), nDetRE * nPost);
     }
     // Abundance random effects
-    SEXP sigmaSqMuSamples_r; 
-    SEXP betaStarSamples_r; 
+    SEXP sigmaSqMuSamples_r;
+    SEXP betaStarSamples_r;
     if (pAbundRE > 0) {
-      PROTECT(sigmaSqMuSamples_r = allocMatrix(REALSXP, pAbundRE, nPost)); nProtect++;
+      PROTECT(sigmaSqMuSamples_r = Rf_allocMatrix(REALSXP, pAbundRE, nPost)); nProtect++;
       zeros(REAL(sigmaSqMuSamples_r), pAbundRE * nPost);
-      PROTECT(betaStarSamples_r = allocMatrix(REALSXP, nAbundRE, nPost)); nProtect++;
+      PROTECT(betaStarSamples_r = Rf_allocMatrix(REALSXP, nAbundRE, nPost)); nProtect++;
       zeros(REAL(betaStarSamples_r), nAbundRE * nPost);
     }
     // Stuff for fitted values
     int KFull = K + 1;
     int nObsFull = KFull * J;
-    SEXP yRepSamples_r; 
-    PROTECT(yRepSamples_r = allocMatrix(INTSXP, nObsFull, nPost)); nProtect++; 
+    SEXP yRepSamples_r;
+    PROTECT(yRepSamples_r = Rf_allocMatrix(INTSXP, nObsFull, nPost)); nProtect++;
     zerosInt(INTEGER(yRepSamples_r), nObsFull * nPost);
-    SEXP piFullSamples_r; 
-    PROTECT(piFullSamples_r = allocMatrix(REALSXP, nObsFull, nPost)); nProtect++; 
+    SEXP piFullSamples_r;
+    PROTECT(piFullSamples_r = Rf_allocMatrix(REALSXP, nObsFull, nPost)); nProtect++;
     zeros(REAL(piFullSamples_r), nObsFull * nPost);
-    
+
     /********************************************************************
       Some constants and temporary variables to be used later
     ********************************************************************/
     int JpAbundRE = J * pAbundRE;
     int JpDetRE = J * pDetRE;
-    double tmp_0, tmp_02; 
+    double tmp_0, tmp_02;
     double *tmp_J = (double *) R_alloc(J, sizeof(double));
     double *tmp_KFull = (double *) R_alloc(KFull, sizeof(double));
-   
+
     // For latent abundance
-    double *mu = (double *) R_alloc(J, sizeof(double)); 
-    zeros(mu, J); 
+    double *mu = (double *) R_alloc(J, sizeof(double));
+    zeros(mu, J);
 
     /********************************************************************
       Set up MH stuff
@@ -276,19 +277,19 @@ extern "C" {
     double *accept = (double *) R_alloc(nAMCMC, sizeof(double)); zeros(accept, nAMCMC);
     double betaAccept = 1;
     double alphaAccept = 1;
-    // Set the initial candidate values for everything to the inital values. 
-    double *betaCand = (double *) R_alloc(pAbund, sizeof(double)); 
+    // Set the initial candidate values for everything to the inital values.
+    double *betaCand = (double *) R_alloc(pAbund, sizeof(double));
     for (j = 0; j < pAbund; j++) {
       betaCand[j] = beta[j];
-    } 
+    }
     double *betaStarCand = (double *) R_alloc(nAbundRE, sizeof(double));
     for (j = 0; j < nAbundRE; j++) {
       betaStarCand[j] = betaStar[j];
     }
-    double *alphaCand = (double *) R_alloc(pDet, sizeof(double)); 
+    double *alphaCand = (double *) R_alloc(pDet, sizeof(double));
     for (j = 0; j < pDet; j++) {
       alphaCand[j] = alpha[j];
-    } 
+    }
     double *alphaStarCand = (double *) R_alloc(nDetRE, sizeof(double));
     for (j = 0; j < nDetRE; j++) {
       alphaStarCand[j] = alphaStar[j];
@@ -304,57 +305,57 @@ extern "C" {
     for (j = 0; j < J; j++) {
       NCand[j] = N[j];
     }
-    SEXP acceptSamples_r; 
-    PROTECT(acceptSamples_r = allocMatrix(REALSXP, nAMCMC, nBatch)); nProtect++; 
+    SEXP acceptSamples_r;
+    PROTECT(acceptSamples_r = Rf_allocMatrix(REALSXP, nAMCMC, nBatch)); nProtect++;
     zeros(REAL(acceptSamples_r), nAMCMC * nBatch);
-    SEXP tuningSamples_r; 
-    PROTECT(tuningSamples_r = allocMatrix(REALSXP, nAMCMC, nBatch)); nProtect++; 
+    SEXP tuningSamples_r;
+    PROTECT(tuningSamples_r = Rf_allocMatrix(REALSXP, nAMCMC, nBatch)); nProtect++;
     zeros(REAL(tuningSamples_r), nAMCMC * nBatch);
 
     /**********************************************************************
      * Prep for random effects
      * *******************************************************************/
     // Site-level sums of the abundance random effects
-    double *betaStarSites = (double *) R_alloc(J, sizeof(double)); 
-    zeros(betaStarSites, J); 
-    double *betaStarSitesCand = (double *) R_alloc(J, sizeof(double)); 
+    double *betaStarSites = (double *) R_alloc(J, sizeof(double));
+    zeros(betaStarSites, J);
+    double *betaStarSitesCand = (double *) R_alloc(J, sizeof(double));
     int *betaStarLongIndx = (int *) R_alloc(JpAbundRE, sizeof(int));
     // Initial sums
     for (j = 0; j < J; j++) {
       for (l = 0; l < pAbundRE; l++) {
         betaStarLongIndx[l * J + j] = which(XRE[l * J + j], betaLevelIndx, nAbundRE);
-        betaStarSites[j] += betaStar[betaStarLongIndx[l * J + j]] * 
+        betaStarSites[j] += betaStar[betaStarLongIndx[l * J + j]] *
                             XRandom[l * J + j];
       }
       betaStarSitesCand[j] = betaStarSites[j];
     }
     // Observation-level sums of the detection random effects
-    double *alphaStarSites = (double *) R_alloc(J, sizeof(double)); 
-    zeros(alphaStarSites, J); 
+    double *alphaStarSites = (double *) R_alloc(J, sizeof(double));
+    zeros(alphaStarSites, J);
     double *alphaStarSitesCand = (double *) R_alloc(J, sizeof(double));
     int *alphaStarLongIndx = (int *) R_alloc(JpDetRE, sizeof(int));
     // Get sums of the current REs for each site/visit combo
     for (j = 0; j < J; j++) {
       for (l = 0; l < pDetRE; l++) {
         alphaStarLongIndx[l * J + j] = which(XpRE[l * J + j], alphaLevelIndx, nDetRE);
-        alphaStarSites[j] += alphaStar[alphaStarLongIndx[l * J + j]] * 
+        alphaStarSites[j] += alphaStar[alphaStarLongIndx[l * J + j]] *
                            XpRandom[l * J + j];
       }
       alphaStarSitesCand[j] = alphaStarSites[j];
     }
     // Starting index for abundance random effects
-    int *betaStarStart = (int *) R_alloc(pAbundRE, sizeof(int)); 
+    int *betaStarStart = (int *) R_alloc(pAbundRE, sizeof(int));
     for (l = 0; l < pAbundRE; l++) {
-      betaStarStart[l] = which(l, betaStarIndx, nAbundRE); 
+      betaStarStart[l] = which(l, betaStarIndx, nAbundRE);
     }
     // Starting index for detection random effects
-    int *alphaStarStart = (int *) R_alloc(pDetRE, sizeof(int)); 
+    int *alphaStarStart = (int *) R_alloc(pDetRE, sizeof(int));
     for (l = 0; l < pDetRE; l++) {
-      alphaStarStart[l] = which(l, alphaStarIndx, nDetRE); 
+      alphaStarStart[l] = which(l, alphaStarIndx, nDetRE);
     }
-    
+
     /**********************************************************************
-     * DS Prep 
+     * DS Prep
      * *******************************************************************/
     double *sigma = (double *) R_alloc(J, sizeof(double));
     double *p = (double *) R_alloc(nObs, sizeof(double)); zeros(p, nObs);
@@ -374,14 +375,14 @@ extern "C" {
         psi[k] = (pow(distBreaks[k + 1], 2) - pow(distBreaks[k], 2)) / pow(stripWidth, 2);
       }
     }
-    double *piFull = (double *) R_alloc(nObsFull, sizeof(double)); 
+    double *piFull = (double *) R_alloc(nObsFull, sizeof(double));
     zeros(piFull, nObsFull);
-    double *piFullCand = (double *) R_alloc(nObsFull, sizeof(double)); 
+    double *piFullCand = (double *) R_alloc(nObsFull, sizeof(double));
     zeros(piFullCand, nObsFull);
     double likeVal = 0.0;
 
 
-    GetRNGstate(); 
+    GetRNGstate();
 
     for (s = 0, g = 0; s < nBatch; s++) {
       for (t = 0; t < batchLength; t++, g++) {
@@ -446,15 +447,15 @@ extern "C" {
 	  }
 	  for (j = 0; j < J; j++) {
             /********************************
-             * Candidate 
+             * Candidate
              *******************************/
-            tmp_0 = 0.0; 
+            tmp_0 = 0.0;
 	    likeVal = 0.0;
-            sigma[j] = exp(F77_NAME(ddot)(&pDet, &Xp[j], &J, alphaCand, &inc) + 
+            sigma[j] = exp(F77_NAME(ddot)(&pDet, &Xp[j], &J, alphaCand, &inc) +
                            alphaStarSites[j]);
             for (k = 0; k < K; k++) {
-              p[k * J + j] = integrate(detModel, distBreaks[k], distBreaks[k + 1], sigma[j], 
-                                       nInt, transect); 
+              p[k * J + j] = integrate(detModel, distBreaks[k], distBreaks[k + 1], sigma[j],
+                                       nInt, transect);
 	      if (transect == 0) {
                 p[k * J + j] /= (distBreaks[k + 1] - distBreaks[k]);
 	      } else {
@@ -468,16 +469,16 @@ extern "C" {
 	    likeVal += (N[j] - yMax[j]) * log(piFullCand[K * J + j]);
 	    logPostAlphaCand += likeVal;
             /********************************
-             * Current 
+             * Current
              *******************************/
 	    if (alphaAccept == 1) {
-              tmp_0 = 0.0; 
+              tmp_0 = 0.0;
 	      likeVal = 0.0;
-              sigma[j] = exp(F77_NAME(ddot)(&pDet, &Xp[j], &J, alpha, &inc) + 
+              sigma[j] = exp(F77_NAME(ddot)(&pDet, &Xp[j], &J, alpha, &inc) +
                              alphaStarSites[j]);
               for (k = 0; k < K; k++) {
-                p[k * J + j] = integrate(detModel, distBreaks[k], distBreaks[k + 1], sigma[j], 
-                                         nInt, transect); 
+                p[k * J + j] = integrate(detModel, distBreaks[k], distBreaks[k + 1], sigma[j],
+                                         nInt, transect);
 	        if (transect == 0) {
                   p[k * J + j] /= (distBreaks[k + 1] - distBreaks[k]);
 	        } else {
@@ -509,18 +510,18 @@ extern "C" {
          *Update abundance random effects variance
          *******************************************************************/
         for (l = 0; l < pAbundRE; l++) {
-          tmp_0 = F77_NAME(ddot)(&nAbundRELong[l], &betaStar[betaStarStart[l]], &inc, &betaStar[betaStarStart[l]], &inc); 
-          tmp_0 *= 0.5; 
-          sigmaSqMu[l] = rigamma(sigmaSqMuA[l] + nAbundRELong[l] / 2.0, sigmaSqMuB[l] + tmp_0); 
+          tmp_0 = F77_NAME(ddot)(&nAbundRELong[l], &betaStar[betaStarStart[l]], &inc, &betaStar[betaStarStart[l]], &inc);
+          tmp_0 *= 0.5;
+          sigmaSqMu[l] = rigamma(sigmaSqMuA[l] + nAbundRELong[l] / 2.0, sigmaSqMuB[l] + tmp_0);
         }
 
         /********************************************************************
          *Update detection  random effects variance
          *******************************************************************/
         for (l = 0; l < pDetRE; l++) {
-          tmp_0 = F77_NAME(ddot)(&nDetRELong[l], &alphaStar[alphaStarStart[l]], &inc, &alphaStar[alphaStarStart[l]], &inc); 
-          tmp_0 *= 0.5; 
-          sigmaSqP[l] = rigamma(sigmaSqPA[l] + nDetRELong[l] / 2.0, sigmaSqPB[l] + tmp_0); 
+          tmp_0 = F77_NAME(ddot)(&nDetRELong[l], &alphaStar[alphaStarStart[l]], &inc, &alphaStar[alphaStarStart[l]], &inc);
+          tmp_0 *= 0.5;
+          sigmaSqP[l] = rigamma(sigmaSqPA[l] + nDetRELong[l] / 2.0, sigmaSqPB[l] + tmp_0);
         }
 
         /********************************************************************
@@ -529,19 +530,19 @@ extern "C" {
         if (pAbundRE > 0) {
           for (l = 0; l < nAbundRE; l++) {
 	    betaStarCand[l] = rnorm(betaStar[l], exp(tuning[betaStarAMCMCIndx + l]));
-            logPostBetaStarCand[l] = dnorm(betaStarCand[l], 0.0, 
+            logPostBetaStarCand[l] = dnorm(betaStarCand[l], 0.0,
 			                   sqrt(sigmaSqMu[betaStarIndx[l]]), 1);
-            logPostBetaStarCurr[l] = dnorm(betaStar[l], 0.0, 
+            logPostBetaStarCurr[l] = dnorm(betaStar[l], 0.0,
 			                   sqrt(sigmaSqMu[betaStarIndx[l]]), 1);
 	    for (j = 0; j < J; j++) {
               if (XRE[betaStarIndx[l] * J + j] == betaLevelIndx[l]) {
                 // Candidate
                 betaStarSitesCand[j] = 0.0;
                 for (ll = 0; ll < pAbundRE; ll++) {
-                  betaStarSitesCand[j] += betaStarCand[betaStarLongIndx[ll * J + j]] * 
+                  betaStarSitesCand[j] += betaStarCand[betaStarLongIndx[ll * J + j]] *
 	                              XRandom[ll * J + j];
                 }
-                tmp_J[j] = exp(F77_NAME(ddot)(&pAbund, &X[j], &J, beta, &inc) + 
+                tmp_J[j] = exp(F77_NAME(ddot)(&pAbund, &X[j], &J, beta, &inc) +
 				  betaStarSitesCand[j]);
                 if (family == 1) {
 		  logPostBetaStarCand[l] += nb_logpost(kappa, N[j], tmp_J[j], offset[j]);
@@ -551,10 +552,10 @@ extern "C" {
 		// Current
                 betaStarSites[j] = 0.0;
                 for (ll = 0; ll < pAbundRE; ll++) {
-                  betaStarSites[j] += betaStar[betaStarLongIndx[ll * J + j]] * 
+                  betaStarSites[j] += betaStar[betaStarLongIndx[ll * J + j]] *
 	                              XRandom[ll * J + j];
                 }
-                tmp_J[j] = exp(F77_NAME(ddot)(&pAbund, &X[j], &J, beta, &inc) + 
+                tmp_J[j] = exp(F77_NAME(ddot)(&pAbund, &X[j], &J, beta, &inc) +
 				  betaStarSites[j]);
                 if (family == 1) {
 		  logPostBetaStarCurr[l] += nb_logpost(kappa, N[j], tmp_J[j], offset[j]);
@@ -580,27 +581,27 @@ extern "C" {
         if (pDetRE > 0) {
           for (l = 0; l < nDetRE; l++) {
 	    alphaStarCand[l] = rnorm(alphaStar[l], exp(tuning[alphaStarAMCMCIndx + l]));
-            logPostAlphaStarCand[l] = dnorm(alphaStarCand[l], 0.0, 
+            logPostAlphaStarCand[l] = dnorm(alphaStarCand[l], 0.0,
 			                   sqrt(sigmaSqP[alphaStarIndx[l]]), 1);
-            logPostAlphaStarCurr[l] = dnorm(alphaStar[l], 0.0, 
+            logPostAlphaStarCurr[l] = dnorm(alphaStar[l], 0.0,
 			                   sqrt(sigmaSqP[alphaStarIndx[l]]), 1);
 	    for (j = 0; j < J; j++) {
               likeVal = 0.0;
-              tmp_0 = 0.0; 
+              tmp_0 = 0.0;
               if ((XpRE[alphaStarIndx[l] * J + j] == alphaLevelIndx[l])) {
                 /********************************
-                 * Candidate 
+                 * Candidate
                  *******************************/
                 alphaStarSitesCand[j] = 0.0;
                 for (ll = 0; ll < pDetRE; ll++) {
-                  alphaStarSitesCand[j] += alphaStarCand[alphaStarLongIndx[ll * J + j]] * 
+                  alphaStarSitesCand[j] += alphaStarCand[alphaStarLongIndx[ll * J + j]] *
 	                              XpRandom[ll * J + j];
                 }
-                sigma[j] = exp(F77_NAME(ddot)(&pDet, &Xp[j], &J, alpha, &inc) + 
+                sigma[j] = exp(F77_NAME(ddot)(&pDet, &Xp[j], &J, alpha, &inc) +
                                alphaStarSitesCand[j]);
                 for (k = 0; k < K; k++) {
-                  p[k * J + j] = integrate(detModel, distBreaks[k], distBreaks[k + 1], sigma[j], 
-                                           nInt, transect); 
+                  p[k * J + j] = integrate(detModel, distBreaks[k], distBreaks[k + 1], sigma[j],
+                                           nInt, transect);
 	          if (transect == 0) {
                     p[k * J + j] /= (distBreaks[k + 1] - distBreaks[k]);
 	          } else {
@@ -620,14 +621,14 @@ extern "C" {
 		tmp_0 = 0.0;
                 alphaStarSites[j] = 0.0;
                 for (ll = 0; ll < pDetRE; ll++) {
-                  alphaStarSites[j] += alphaStar[alphaStarLongIndx[ll * J + j]] * 
+                  alphaStarSites[j] += alphaStar[alphaStarLongIndx[ll * J + j]] *
 	                              XpRandom[ll * J + j];
                 }
-                sigma[j] = exp(F77_NAME(ddot)(&pDet, &Xp[j], &J, alpha, &inc) + 
+                sigma[j] = exp(F77_NAME(ddot)(&pDet, &Xp[j], &J, alpha, &inc) +
                                alphaStarSites[j]);
                 for (k = 0; k < K; k++) {
-                  p[k * J + j] = integrate(detModel, distBreaks[k], distBreaks[k + 1], sigma[j], 
-                                           nInt, transect); 
+                  p[k * J + j] = integrate(detModel, distBreaks[k], distBreaks[k + 1], sigma[j],
+                                           nInt, transect);
 	          if (transect == 0) {
                     p[k * J + j] /= (distBreaks[k + 1] - distBreaks[k]);
 	          } else {
@@ -659,12 +660,12 @@ extern "C" {
          *Update kappa (the NB size parameter)
          *******************************************************************/
 	if (family == 1) {
-          kappaCand = logitInv(rnorm(logit(kappa, kappaA, kappaB), exp(tuning[kappaAMCMCIndx])), 
+          kappaCand = logitInv(rnorm(logit(kappa, kappaA, kappaB), exp(tuning[kappaAMCMCIndx])),
 			       kappaA, kappaB);
 	  logPostKappaCurr = 0.0;
 	  logPostKappaCand = 0.0;
 	  for (j = 0; j < J; j++) {
-            mu[j] = exp(F77_NAME(ddot)(&pAbund, &X[j], &J, beta, &inc) + 
+            mu[j] = exp(F77_NAME(ddot)(&pAbund, &X[j], &J, beta, &inc) +
                         betaStarSites[j]);
             logPostKappaCurr += nb_logpost(kappa, N[j], mu[j], offset[j]);
 	    logPostKappaCand += nb_logpost(kappaCand, N[j], mu[j], offset[j]);
@@ -679,7 +680,7 @@ extern "C" {
 	}
 
         /********************************************************************
-         *Update Latent Abundance 
+         *Update Latent Abundance
          *******************************************************************/
 	zeros(logPostCurrN, J);
 	zeros(logPostCandN, J);
@@ -688,7 +689,7 @@ extern "C" {
           NCand[j] = rpois(N[j] + epsilonN);
 	  // Only calculate if Poisson since its already calculated in kappa update
 	  if (family == 0) {
-            mu[j] = exp(F77_NAME(ddot)(&pAbund, &X[j], &J, beta, &inc) + 
+            mu[j] = exp(F77_NAME(ddot)(&pAbund, &X[j], &J, beta, &inc) +
                         betaStarSites[j]);
 	  }
 	  // Likelihood contribution
@@ -696,15 +697,15 @@ extern "C" {
 	    likeVal = 0.0;
 	    tmp_0 = 0.0;
 	    for (k = 0; k < K; k++) {
-              likeVal += y[k * J + j] * log(piFull[k * J + j]);  
+              likeVal += y[k * J + j] * log(piFull[k * J + j]);
 	      // Save piFull value for calculting fitted vals.
               tmp_KFull[k] = piFull[k * J + j];
 	    }
             /********************************
              * Current
              *******************************/
-	    logPostCurrN[j] += likeVal + 
-                               ((N[j] - yMax[j]) * log(piFull[K * J + j])) + 
+	    logPostCurrN[j] += likeVal +
+                               ((N[j] - yMax[j]) * log(piFull[K * J + j])) +
                                lgammafn(N[j] + 1.0) -
 			       lgammafn(N[j] - yMax[j] + 1.0);
 	    // Contribution from NB or Poisson
@@ -718,8 +719,8 @@ extern "C" {
             /********************************
              * Candidate
              *******************************/
-	    logPostCandN[j] += likeVal + 
-                               ((NCand[j] - yMax[j]) * log(piFull[K * J + j])) + 
+	    logPostCandN[j] += likeVal +
+                               ((NCand[j] - yMax[j]) * log(piFull[K * J + j])) +
                                lgammafn(NCand[j] + 1.0) -
 			       lgammafn(NCand[j] - yMax[j] + 1.0);
 	    if (family == 0) {
@@ -739,53 +740,53 @@ extern "C" {
          *Save samples
          *******************************************************************/
         if (g >= nBurn) {
-          thinIndx++; 
+          thinIndx++;
           if (thinIndx == nThin) {
             F77_NAME(dcopy)(&pAbund, beta, &inc, &REAL(betaSamples_r)[sPost*pAbund], &inc);
             F77_NAME(dcopy)(&pDet, alpha, &inc, &REAL(alphaSamples_r)[sPost*pDet], &inc);
 	    if (family == 1) {
 	      REAL(kappaSamples_r)[sPost] = kappa;
 	    }
-            F77_NAME(dcopy)(&J, mu, &inc, &REAL(muSamples_r)[sPost*J], &inc); 
-            F77_NAME(dcopy)(&J, N, &inc, &REAL(NSamples_r)[sPost*J], &inc); 
-	    // Generate and save replicate values. 
-	    for (j = 0; j < J; j++) { 
+            F77_NAME(dcopy)(&J, mu, &inc, &REAL(muSamples_r)[sPost*J], &inc);
+            F77_NAME(dcopy)(&J, N, &inc, &REAL(NSamples_r)[sPost*J], &inc);
+	    // Generate and save replicate values.
+	    for (j = 0; j < J; j++) {
               for (k = 0; k < KFull; k++) {
                 tmp_KFull[k] = piFull[k * J + j];
 		REAL(piFullSamples_r)[sPost * nObsFull + j * KFull + k] = piFull[k * J + j];
-	      } 
+	      }
 	      if (family == 0) {
                 tmp_0 = rpois(mu[j] * offset[j]);
 	      } else {
                 tmp_0 = rnbinom_mu(mu[j] * offset[j], kappa);
 	      }
-	      rmultinom(tmp_0, tmp_KFull, KFull, 
+	      rmultinom(tmp_0, tmp_KFull, KFull,
                         &INTEGER(yRepSamples_r)[sPost * nObsFull + j * KFull]);
 	    }
             if (pAbundRE > 0) {
-              F77_NAME(dcopy)(&pAbundRE, sigmaSqMu, &inc, 
+              F77_NAME(dcopy)(&pAbundRE, sigmaSqMu, &inc,
           		    &REAL(sigmaSqMuSamples_r)[sPost*pAbundRE], &inc);
-              F77_NAME(dcopy)(&nAbundRE, betaStar, &inc, 
+              F77_NAME(dcopy)(&nAbundRE, betaStar, &inc,
           		    &REAL(betaStarSamples_r)[sPost*nAbundRE], &inc);
             }
             if (pDetRE > 0) {
-              F77_NAME(dcopy)(&pDetRE, sigmaSqP, &inc, 
+              F77_NAME(dcopy)(&pDetRE, sigmaSqP, &inc,
                   	      &REAL(sigmaSqPSamples_r)[sPost*pDetRE], &inc);
-              F77_NAME(dcopy)(&nDetRE, alphaStar, &inc, 
+              F77_NAME(dcopy)(&nDetRE, alphaStar, &inc,
                   	      &REAL(alphaStarSamples_r)[sPost*nDetRE], &inc);
             }
-            sPost++; 
-            thinIndx = 0; 
+            sPost++;
+            thinIndx = 0;
           }
         }
         R_CheckUserInterrupt();
       } // t (end batch)
       /********************************************************************
-       *Adjust tuning 
+       *Adjust tuning
        *******************************************************************/
       for (j = 0; j < nAMCMC; j++) {
-        REAL(acceptSamples_r)[s * nAMCMC + j] = accept[j]/batchLength; 
-        REAL(tuningSamples_r)[s * nAMCMC + j] = tuning[j]; 
+        REAL(acceptSamples_r)[s * nAMCMC + j] = accept[j]/batchLength;
+        REAL(tuningSamples_r)[s * nAMCMC + j] = tuning[j];
         if (accept[j] / batchLength > acceptRate) {
           tuning[j] += std::min(0.01, 1.0/sqrt(static_cast<double>(s)));
         } else{
@@ -795,12 +796,12 @@ extern "C" {
       }
 
       /********************************************************************
-       *Report 
+       *Report
        *******************************************************************/
       if (verbose) {
         if (status == nReport) {
           Rprintf("Batch: %i of %i, %3.2f%%\n", s, nBatch, 100.0*s/nBatch);
-          Rprintf("\tParameter\tAcceptance\tTuning\n");	  
+          Rprintf("\tParameter\tAcceptance\tTuning\n");
           for (j = 0; j < pAbund; j++) {
             Rprintf("\tbeta[%i]\t\t%3.1f\t\t%1.5f\n", j + 1, 100.0*REAL(acceptSamples_r)[s * nAMCMC + betaAMCMCIndx + j], exp(tuning[betaAMCMCIndx + j]));
           }
@@ -816,8 +817,8 @@ extern "C" {
           #endif
           status = 0;
         }
-      } 
-      status++;        
+      }
+      status++;
 
     } // all batches
     if (verbose) {
@@ -828,7 +829,7 @@ extern "C" {
     SEXP result_r, resultName_r;
     int nResultListObjs = 7;
     if (pDetRE > 0) {
-      nResultListObjs += 2; 
+      nResultListObjs += 2;
     }
     if (pAbundRE > 0) {
       nResultListObjs += 2;
@@ -837,19 +838,19 @@ extern "C" {
       nResultListObjs += 1;
     }
 
-    PROTECT(result_r = allocVector(VECSXP, nResultListObjs)); nProtect++;
-    PROTECT(resultName_r = allocVector(VECSXP, nResultListObjs)); nProtect++;
+    PROTECT(result_r = Rf_allocVector(VECSXP, nResultListObjs)); nProtect++;
+    PROTECT(resultName_r = Rf_allocVector(VECSXP, nResultListObjs)); nProtect++;
 
     // Setting the components of the output list.
     SET_VECTOR_ELT(result_r, 0, betaSamples_r);
     SET_VECTOR_ELT(result_r, 1, alphaSamples_r);
-    SET_VECTOR_ELT(result_r, 2, NSamples_r); 
+    SET_VECTOR_ELT(result_r, 2, NSamples_r);
     SET_VECTOR_ELT(result_r, 3, muSamples_r);
     SET_VECTOR_ELT(result_r, 4, tuningSamples_r);
     SET_VECTOR_ELT(result_r, 5, yRepSamples_r);
     SET_VECTOR_ELT(result_r, 6, piFullSamples_r);
     if (pDetRE > 0) {
-      tmp_0 = 7; // Needed to make tracking kappa easier. 
+      tmp_0 = 7; // Needed to make tracking kappa easier.
       SET_VECTOR_ELT(result_r, 7, sigmaSqPSamples_r);
       SET_VECTOR_ELT(result_r, 8, alphaStarSamples_r);
     }
@@ -867,33 +868,33 @@ extern "C" {
         tmp_02 = tmp_0 + 2;
       } else {
         tmp_02 = 7;
-      }  
+      }
       SET_VECTOR_ELT(result_r, tmp_02, kappaSamples_r);
     }
 
-    SET_VECTOR_ELT(resultName_r, 0, mkChar("beta.samples")); 
-    SET_VECTOR_ELT(resultName_r, 1, mkChar("alpha.samples")); 
-    SET_VECTOR_ELT(resultName_r, 2, mkChar("N.samples")); 
-    SET_VECTOR_ELT(resultName_r, 3, mkChar("mu.samples"));
-    SET_VECTOR_ELT(resultName_r, 4, mkChar("tuning.samples"));
-    SET_VECTOR_ELT(resultName_r, 5, mkChar("y.rep.samples"));
-    SET_VECTOR_ELT(resultName_r, 6, mkChar("pi.samples"));
+    SET_VECTOR_ELT(resultName_r, 0, Rf_mkChar("beta.samples"));
+    SET_VECTOR_ELT(resultName_r, 1, Rf_mkChar("alpha.samples"));
+    SET_VECTOR_ELT(resultName_r, 2, Rf_mkChar("N.samples"));
+    SET_VECTOR_ELT(resultName_r, 3, Rf_mkChar("mu.samples"));
+    SET_VECTOR_ELT(resultName_r, 4, Rf_mkChar("tuning.samples"));
+    SET_VECTOR_ELT(resultName_r, 5, Rf_mkChar("y.rep.samples"));
+    SET_VECTOR_ELT(resultName_r, 6, Rf_mkChar("pi.samples"));
     if (pDetRE > 0) {
-      SET_VECTOR_ELT(resultName_r, 7, mkChar("sigma.sq.p.samples")); 
-      SET_VECTOR_ELT(resultName_r, 8, mkChar("alpha.star.samples")); 
+      SET_VECTOR_ELT(resultName_r, 7, Rf_mkChar("sigma.sq.p.samples"));
+      SET_VECTOR_ELT(resultName_r, 8, Rf_mkChar("alpha.star.samples"));
     }
     if (pAbundRE > 0) {
-      SET_VECTOR_ELT(resultName_r, tmp_0, mkChar("sigma.sq.mu.samples")); 
-      SET_VECTOR_ELT(resultName_r, tmp_0 + 1, mkChar("beta.star.samples")); 
+      SET_VECTOR_ELT(resultName_r, tmp_0, Rf_mkChar("sigma.sq.mu.samples"));
+      SET_VECTOR_ELT(resultName_r, tmp_0 + 1, Rf_mkChar("beta.star.samples"));
     }
     if (family == 1) {
-      SET_VECTOR_ELT(resultName_r, tmp_02, mkChar("kappa.samples")); 
+      SET_VECTOR_ELT(resultName_r, tmp_02, Rf_mkChar("kappa.samples"));
     }
-   
-    namesgets(result_r, resultName_r);
-    
+
+    Rf_namesgets(result_r, resultName_r);
+
     UNPROTECT(nProtect);
-    
+
     return(result_r);
   }
 }
