@@ -7,6 +7,7 @@
 #include <omp.h>
 #endif
 
+#define R_NO_REMAP
 #include <R.h>
 #include <Rmath.h>
 #include <Rinternals.h>
@@ -18,23 +19,23 @@
 #endif
 
 extern "C" {
-  SEXP NMix(SEXP y_r, SEXP X_r, SEXP Xp_r, SEXP XRE_r, SEXP XpRE_r, 
+  SEXP NMix(SEXP y_r, SEXP X_r, SEXP Xp_r, SEXP XRE_r, SEXP XpRE_r,
             SEXP XRandom_r, SEXP XpRandom_r, SEXP yMax_r,
             SEXP consts_r, SEXP K_r, SEXP nAbundRELong_r, SEXP nDetRELong_r,
             SEXP betaStarting_r, SEXP alphaStarting_r, SEXP kappaStarting_r,
             SEXP sigmaSqMuStarting_r, SEXP sigmaSqPStarting_r,
             SEXP betaStarStarting_r, SEXP alphaStarStarting_r, SEXP NStarting_r,
-            SEXP NLongIndx_r, SEXP betaStarIndx_r, SEXP betaLevelIndx_r, 
-	    SEXP alphaStarIndx_r, SEXP alphaLevelIndx_r,
-	    SEXP muBeta_r, SEXP SigmaBeta_r, 
-	    SEXP muAlpha_r, SEXP SigmaAlpha_r, 
-            SEXP sigmaSqMuA_r, SEXP sigmaSqMuB_r, 
-            SEXP sigmaSqPA_r, SEXP sigmaSqPB_r, 
-	    SEXP kappaA_r, SEXP kappaB_r, SEXP tuning_r,
-	    SEXP nBatch_r, SEXP batchLength_r, SEXP acceptRate_r, SEXP nThreads_r, 
+            SEXP NLongIndx_r, SEXP betaStarIndx_r, SEXP betaLevelIndx_r,
+            SEXP alphaStarIndx_r, SEXP alphaLevelIndx_r,
+            SEXP muBeta_r, SEXP SigmaBeta_r,
+            SEXP muAlpha_r, SEXP SigmaAlpha_r,
+            SEXP sigmaSqMuA_r, SEXP sigmaSqMuB_r,
+            SEXP sigmaSqPA_r, SEXP sigmaSqPB_r,
+            SEXP kappaA_r, SEXP kappaB_r, SEXP tuning_r,
+            SEXP nBatch_r, SEXP batchLength_r, SEXP acceptRate_r, SEXP nThreads_r,
             SEXP verbose_r, SEXP nReport_r, SEXP samplesInfo_r,
-	    SEXP chainInfo_r, SEXP family_r, SEXP offset_r){
-   
+            SEXP chainInfo_r, SEXP family_r, SEXP offset_r){
+
     /**********************************************************************
      * Initial constants
      * *******************************************************************/
@@ -42,7 +43,7 @@ extern "C" {
     const int inc = 1;
     const double one = 1.0;
     const double zero = 0.0;
-    
+
     /**********************************************************************
      * Get Inputs
      * *******************************************************************/
@@ -51,7 +52,7 @@ extern "C" {
     double *Xp = REAL(Xp_r);
     double *yMax = REAL(yMax_r);
     double *offset = REAL(offset_r);
-    int *XRE = INTEGER(XRE_r); 
+    int *XRE = INTEGER(XRE_r);
     int *XpRE = INTEGER(XpRE_r);
     double *XRandom = REAL(XRandom_r);
     double *XpRandom = REAL(XpRandom_r);
@@ -65,34 +66,34 @@ extern "C" {
     int pDetRE = INTEGER(consts_r)[6];
     int nDetRE = INTEGER(consts_r)[7];
     int ppDet = pDet * pDet;
-    int ppAbund = pAbund * pAbund; 
-    double *muBeta = (double *) R_alloc(pAbund, sizeof(double));   
+    int ppAbund = pAbund * pAbund;
+    double *muBeta = (double *) R_alloc(pAbund, sizeof(double));
     F77_NAME(dcopy)(&pAbund, REAL(muBeta_r), &inc, muBeta, &inc);
-    double *muAlpha = (double *) R_alloc(pDet, sizeof(double));   
+    double *muAlpha = (double *) R_alloc(pDet, sizeof(double));
     F77_NAME(dcopy)(&pDet, REAL(muAlpha_r), &inc, muAlpha, &inc);
-    double *SigmaBeta = (double *) R_alloc(ppAbund, sizeof(double));   
+    double *SigmaBeta = (double *) R_alloc(ppAbund, sizeof(double));
     F77_NAME(dcopy)(&ppAbund, REAL(SigmaBeta_r), &inc, SigmaBeta, &inc);
-    double *SigmaAlpha = (double *) R_alloc(ppDet, sizeof(double));   
+    double *SigmaAlpha = (double *) R_alloc(ppDet, sizeof(double));
     F77_NAME(dcopy)(&ppDet, REAL(SigmaAlpha_r), &inc, SigmaAlpha, &inc);
-    double *sigmaSqMuA = REAL(sigmaSqMuA_r); 
-    double *sigmaSqMuB = REAL(sigmaSqMuB_r); 
-    double *sigmaSqPA = REAL(sigmaSqPA_r); 
-    double *sigmaSqPB = REAL(sigmaSqPB_r); 
+    double *sigmaSqMuA = REAL(sigmaSqMuA_r);
+    double *sigmaSqMuB = REAL(sigmaSqMuB_r);
+    double *sigmaSqPA = REAL(sigmaSqPA_r);
+    double *sigmaSqPB = REAL(sigmaSqPB_r);
     double kappaA = REAL(kappaA_r)[0];
     double kappaB = REAL(kappaB_r)[0];
-    int *nAbundRELong = INTEGER(nAbundRELong_r); 
-    int *nDetRELong = INTEGER(nDetRELong_r); 
-    int *NLongIndx = INTEGER(NLongIndx_r); 
-    int *alphaStarIndx = INTEGER(alphaStarIndx_r); 
+    int *nAbundRELong = INTEGER(nAbundRELong_r);
+    int *nDetRELong = INTEGER(nDetRELong_r);
+    int *NLongIndx = INTEGER(NLongIndx_r);
+    int *alphaStarIndx = INTEGER(alphaStarIndx_r);
     int *alphaLevelIndx = INTEGER(alphaLevelIndx_r);
-    int *betaStarIndx = INTEGER(betaStarIndx_r); 
+    int *betaStarIndx = INTEGER(betaStarIndx_r);
     int *betaLevelIndx = INTEGER(betaLevelIndx_r);
-    int nBatch = INTEGER(nBatch_r)[0]; 
-    int batchLength = INTEGER(batchLength_r)[0]; 
-    int nSamples = nBatch * batchLength; 
-    int nBurn = INTEGER(samplesInfo_r)[0]; 
+    int nBatch = INTEGER(nBatch_r)[0];
+    int batchLength = INTEGER(batchLength_r)[0];
+    int nSamples = nBatch * batchLength;
+    int nBurn = INTEGER(samplesInfo_r)[0];
     int nThin = INTEGER(samplesInfo_r)[1];
-    int nPost = INTEGER(samplesInfo_r)[2]; 
+    int nPost = INTEGER(samplesInfo_r)[2];
     int currChain = INTEGER(chainInfo_r)[0];
     double acceptRate = REAL(acceptRate_r)[0];
     double *tuning = REAL(tuning_r);
@@ -100,9 +101,9 @@ extern "C" {
     int nThreads = INTEGER(nThreads_r)[0];
     int verbose = INTEGER(verbose_r)[0];
     int nReport = INTEGER(nReport_r)[0];
-    int status = 0; 
+    int status = 0;
     int thinIndx = 0;
-    int sPost = 0;  
+    int sPost = 0;
     // NB = 1, Poisson = 0;
     int family = INTEGER(family_r)[0];
 
@@ -110,13 +111,13 @@ extern "C" {
     omp_set_num_threads(nThreads);
 #else
     if(nThreads > 1){
-      warning("n.omp.threads > 1, but source not compiled with OpenMP support.");
+      Rf_warning("n.omp.threads > 1, but source not compiled with OpenMP support.");
       nThreads = 1;
     }
 #endif
-    
+
     /**********************************************************************
-     * Print Information 
+     * Print Information
      * *******************************************************************/
     if(verbose){
       if (currChain == 1) {
@@ -129,10 +130,10 @@ extern "C" {
           Rprintf("Poisson N-mixture model with %i sites.\n\n", J);
 	}
         Rprintf("Samples per Chain: %i (%i batches of length %i)\n", nSamples, nBatch, batchLength);
-        Rprintf("Burn-in: %i \n", nBurn); 
-        Rprintf("Thinning Rate: %i \n", nThin); 
+        Rprintf("Burn-in: %i \n", nBurn);
+        Rprintf("Thinning Rate: %i \n", nThin);
         Rprintf("Number of Chains: %i \n", nChain);
-        Rprintf("Total Posterior Samples: %i \n\n", nPost * nChain); 
+        Rprintf("Total Posterior Samples: %i \n\n", nPost * nChain);
 #ifdef _OPENMP
         Rprintf("Source compiled with OpenMP support and model fit using %i thread(s).\n\n", nThreads);
 #else
@@ -152,80 +153,80 @@ extern "C" {
     /**********************************************************************
      * Parameters
      * *******************************************************************/
-    // Abundance Covariates 
-    double *beta = (double *) R_alloc(pAbund, sizeof(double));   
+    // Abundance Covariates
+    double *beta = (double *) R_alloc(pAbund, sizeof(double));
     F77_NAME(dcopy)(&pAbund, REAL(betaStarting_r), &inc, beta, &inc);
     // Abundance random effect variances
-    double *sigmaSqMu = (double *) R_alloc(pAbundRE, sizeof(double)); 
-    F77_NAME(dcopy)(&pAbundRE, REAL(sigmaSqMuStarting_r), &inc, sigmaSqMu, &inc); 
+    double *sigmaSqMu = (double *) R_alloc(pAbundRE, sizeof(double));
+    F77_NAME(dcopy)(&pAbundRE, REAL(sigmaSqMuStarting_r), &inc, sigmaSqMu, &inc);
     // Latent random effects
-    double *betaStar = (double *) R_alloc(nAbundRE, sizeof(double)); 
-    F77_NAME(dcopy)(&nAbundRE, REAL(betaStarStarting_r), &inc, betaStar, &inc); 
+    double *betaStar = (double *) R_alloc(nAbundRE, sizeof(double));
+    F77_NAME(dcopy)(&nAbundRE, REAL(betaStarStarting_r), &inc, betaStar, &inc);
     // Detection covariates
-    double *alpha = (double *) R_alloc(pDet, sizeof(double));   
+    double *alpha = (double *) R_alloc(pDet, sizeof(double));
     F77_NAME(dcopy)(&pDet, REAL(alphaStarting_r), &inc, alpha, &inc);
     // Detection random effect variances
-    double *sigmaSqP = (double *) R_alloc(pDetRE, sizeof(double)); 
-    F77_NAME(dcopy)(&pDetRE, REAL(sigmaSqPStarting_r), &inc, sigmaSqP, &inc); 
+    double *sigmaSqP = (double *) R_alloc(pDetRE, sizeof(double));
+    F77_NAME(dcopy)(&pDetRE, REAL(sigmaSqPStarting_r), &inc, sigmaSqP, &inc);
     // Latent detection random effects
-    double *alphaStar = (double *) R_alloc(nDetRE, sizeof(double)); 
-    F77_NAME(dcopy)(&nDetRE, REAL(alphaStarStarting_r), &inc, alphaStar, &inc); 
+    double *alphaStar = (double *) R_alloc(nDetRE, sizeof(double));
+    F77_NAME(dcopy)(&nDetRE, REAL(alphaStarStarting_r), &inc, alphaStar, &inc);
     // Size parameter
     double kappa = REAL(kappaStarting_r)[0];
     // Latent Abundance
-    double *N = (double *) R_alloc(J, sizeof(double));   
+    double *N = (double *) R_alloc(J, sizeof(double));
     F77_NAME(dcopy)(&J, REAL(NStarting_r), &inc, N, &inc);
 
     /**********************************************************************
      * Return Stuff
      * *******************************************************************/
     SEXP betaSamples_r;
-    PROTECT(betaSamples_r = allocMatrix(REALSXP, pAbund, nPost)); nProtect++;
+    PROTECT(betaSamples_r = Rf_allocMatrix(REALSXP, pAbund, nPost)); nProtect++;
     zeros(REAL(betaSamples_r), pAbund * nPost);
-    SEXP alphaSamples_r; 
-    PROTECT(alphaSamples_r = allocMatrix(REALSXP, pDet, nPost)); nProtect++;
+    SEXP alphaSamples_r;
+    PROTECT(alphaSamples_r = Rf_allocMatrix(REALSXP, pDet, nPost)); nProtect++;
     zeros(REAL(alphaSamples_r), pDet * nPost);
-    SEXP NSamples_r; 
-    PROTECT(NSamples_r = allocMatrix(REALSXP, J, nPost)); nProtect++; 
+    SEXP NSamples_r;
+    PROTECT(NSamples_r = Rf_allocMatrix(REALSXP, J, nPost)); nProtect++;
     zeros(REAL(NSamples_r), J * nPost);
     SEXP kappaSamples_r;
     if (family == 1) {
-      PROTECT(kappaSamples_r = allocMatrix(REALSXP, inc, nPost)); nProtect++;
+      PROTECT(kappaSamples_r = Rf_allocMatrix(REALSXP, inc, nPost)); nProtect++;
       zeros(REAL(kappaSamples_r), nPost);
     }
-    SEXP muSamples_r; 
-    PROTECT(muSamples_r = allocMatrix(REALSXP, J, nPost)); nProtect++; 
+    SEXP muSamples_r;
+    PROTECT(muSamples_r = Rf_allocMatrix(REALSXP, J, nPost)); nProtect++;
     zeros(REAL(muSamples_r), J * nPost);
     // Detection random effects
-    SEXP sigmaSqPSamples_r; 
-    SEXP alphaStarSamples_r; 
+    SEXP sigmaSqPSamples_r;
+    SEXP alphaStarSamples_r;
     if (pDetRE > 0) {
-      PROTECT(sigmaSqPSamples_r = allocMatrix(REALSXP, pDetRE, nPost)); nProtect++;
+      PROTECT(sigmaSqPSamples_r = Rf_allocMatrix(REALSXP, pDetRE, nPost)); nProtect++;
       zeros(REAL(sigmaSqPSamples_r), pDetRE * nPost);
-      PROTECT(alphaStarSamples_r = allocMatrix(REALSXP, nDetRE, nPost)); nProtect++;
+      PROTECT(alphaStarSamples_r = Rf_allocMatrix(REALSXP, nDetRE, nPost)); nProtect++;
       zeros(REAL(alphaStarSamples_r), nDetRE * nPost);
     }
     // Abundance random effects
-    SEXP sigmaSqMuSamples_r; 
-    SEXP betaStarSamples_r; 
+    SEXP sigmaSqMuSamples_r;
+    SEXP betaStarSamples_r;
     if (pAbundRE > 0) {
-      PROTECT(sigmaSqMuSamples_r = allocMatrix(REALSXP, pAbundRE, nPost)); nProtect++;
+      PROTECT(sigmaSqMuSamples_r = Rf_allocMatrix(REALSXP, pAbundRE, nPost)); nProtect++;
       zeros(REAL(sigmaSqMuSamples_r), pAbundRE * nPost);
-      PROTECT(betaStarSamples_r = allocMatrix(REALSXP, nAbundRE, nPost)); nProtect++;
+      PROTECT(betaStarSamples_r = Rf_allocMatrix(REALSXP, nAbundRE, nPost)); nProtect++;
       zeros(REAL(betaStarSamples_r), nAbundRE * nPost);
     }
-    
+
     /********************************************************************
       Some constants and temporary variables to be used later
     ********************************************************************/
-    double tmp_0, tmp_02; 
-    double *tmp_nObs = (double *) R_alloc(nObs, sizeof(double)); 
+    double tmp_0, tmp_02;
+    double *tmp_nObs = (double *) R_alloc(nObs, sizeof(double));
     double *tmp_J = (double *) R_alloc(J, sizeof(double));
-   
+
     // For latent abundance
     double *detProb = (double *) R_alloc(nObs, sizeof(double)); zeros(detProb, nObs);
-    double *mu = (double *) R_alloc(J, sizeof(double)); 
-    zeros(mu, J); 
+    double *mu = (double *) R_alloc(J, sizeof(double));
+    zeros(mu, J);
 
     /********************************************************************
       Set up MH stuff
@@ -261,19 +262,19 @@ extern "C" {
     int alphaStarAMCMCIndx = betaStarAMCMCIndx + nAbundRE;
     int kappaAMCMCIndx = alphaStarAMCMCIndx + nDetRE;
     double *accept = (double *) R_alloc(nAMCMC, sizeof(double)); zeros(accept, nAMCMC);
-    // Set the initial candidate values for everything to the inital values. 
-    double *betaCand = (double *) R_alloc(pAbund, sizeof(double)); 
+    // Set the initial candidate values for everything to the inital values.
+    double *betaCand = (double *) R_alloc(pAbund, sizeof(double));
     for (j = 0; j < pAbund; j++) {
       betaCand[j] = beta[j];
-    } 
+    }
     double *betaStarCand = (double *) R_alloc(nAbundRE, sizeof(double));
     for (j = 0; j < nAbundRE; j++) {
       betaStarCand[j] = betaStar[j];
     }
-    double *alphaCand = (double *) R_alloc(pDet, sizeof(double)); 
+    double *alphaCand = (double *) R_alloc(pDet, sizeof(double));
     for (j = 0; j < pDet; j++) {
       alphaCand[j] = alpha[j];
-    } 
+    }
     double *alphaStarCand = (double *) R_alloc(nDetRE, sizeof(double));
     for (j = 0; j < nDetRE; j++) {
       alphaStarCand[j] = alphaStar[j];
@@ -289,52 +290,52 @@ extern "C" {
     for (j = 0; j < J; j++) {
       NCand[j] = N[j];
     }
-    SEXP acceptSamples_r; 
-    PROTECT(acceptSamples_r = allocMatrix(REALSXP, nAMCMC, nBatch)); nProtect++; 
+    SEXP acceptSamples_r;
+    PROTECT(acceptSamples_r = Rf_allocMatrix(REALSXP, nAMCMC, nBatch)); nProtect++;
     zeros(REAL(acceptSamples_r), nAMCMC * nBatch);
-    SEXP tuningSamples_r; 
-    PROTECT(tuningSamples_r = allocMatrix(REALSXP, nAMCMC, nBatch)); nProtect++; 
+    SEXP tuningSamples_r;
+    PROTECT(tuningSamples_r = Rf_allocMatrix(REALSXP, nAMCMC, nBatch)); nProtect++;
     zeros(REAL(tuningSamples_r), nAMCMC * nBatch);
 
     /**********************************************************************
      * Prep for random effects
      * *******************************************************************/
     // Site-level sums of the abundance random effects
-    double *betaStarSites = (double *) R_alloc(J, sizeof(double)); 
-    zeros(betaStarSites, J); 
-    double *betaStarSitesCand = (double *) R_alloc(J, sizeof(double)); 
+    double *betaStarSites = (double *) R_alloc(J, sizeof(double));
+    zeros(betaStarSites, J);
+    double *betaStarSitesCand = (double *) R_alloc(J, sizeof(double));
     // Initial sums
     for (j = 0; j < J; j++) {
       for (l = 0; l < pAbundRE; l++) {
-        betaStarSites[j] += betaStar[which(XRE[l * J + j], betaLevelIndx, nAbundRE)] * 
+        betaStarSites[j] += betaStar[which(XRE[l * J + j], betaLevelIndx, nAbundRE)] *
                             XRandom[l * J + j];
       }
       betaStarSitesCand[j] = betaStarSites[j];
     }
     // Observation-level sums of the detection random effects
-    double *alphaStarObs = (double *) R_alloc(nObs, sizeof(double)); 
-    zeros(alphaStarObs, nObs); 
+    double *alphaStarObs = (double *) R_alloc(nObs, sizeof(double));
+    zeros(alphaStarObs, nObs);
     double *alphaStarObsCand = (double *) R_alloc(nObs, sizeof(double));
     // Get sums of the current REs for each site/visit combo
     for (i = 0; i < nObs; i++) {
       for (l = 0; l < pDetRE; l++) {
-        alphaStarObs[i] += alphaStar[which(XpRE[l * nObs + i], alphaLevelIndx, nDetRE)] * 
+        alphaStarObs[i] += alphaStar[which(XpRE[l * nObs + i], alphaLevelIndx, nDetRE)] *
                            XpRandom[l * nObs + i];
       }
       alphaStarObsCand[i] = alphaStarObs[i];
     }
     // Starting index for abundance random effects
-    int *betaStarStart = (int *) R_alloc(pAbundRE, sizeof(int)); 
+    int *betaStarStart = (int *) R_alloc(pAbundRE, sizeof(int));
     for (l = 0; l < pAbundRE; l++) {
-      betaStarStart[l] = which(l, betaStarIndx, nAbundRE); 
+      betaStarStart[l] = which(l, betaStarIndx, nAbundRE);
     }
     // Starting index for detection random effects
-    int *alphaStarStart = (int *) R_alloc(pDetRE, sizeof(int)); 
+    int *alphaStarStart = (int *) R_alloc(pDetRE, sizeof(int));
     for (l = 0; l < pDetRE; l++) {
-      alphaStarStart[l] = which(l, alphaStarIndx, nDetRE); 
+      alphaStarStart[l] = which(l, alphaStarIndx, nDetRE);
     }
 
-    GetRNGstate(); 
+    GetRNGstate();
 
     for (s = 0, g = 0; s < nBatch; s++) {
       for (t = 0; t < batchLength; t++, g++) {
@@ -371,7 +372,7 @@ extern "C" {
             betaCand[k] = beta[k];
 	  }
         }
-        
+
 	/********************************************************************
          *Update Detection Regression Coefficients
          *******************************************************************/
@@ -386,12 +387,12 @@ extern "C" {
           }
           for (i = 0; i < nObs; i++) {
             if (N[NLongIndx[i]] > 0.0) {
-              tmp_nObs[i] = logitInv(F77_NAME(ddot)(&pDet, &Xp[i], &nObs, alphaCand, &inc) + 
+              tmp_nObs[i] = logitInv(F77_NAME(ddot)(&pDet, &Xp[i], &nObs, alphaCand, &inc) +
 			             alphaStarObs[i], zero, one);
-              logPostAlphaCand += dbinom(y[i], N[NLongIndx[i]], tmp_nObs[i], 1);	     
-              tmp_nObs[i] = logitInv(F77_NAME(ddot)(&pDet, &Xp[i], &nObs, alpha, &inc) + 
+              logPostAlphaCand += dbinom(y[i], N[NLongIndx[i]], tmp_nObs[i], 1);
+              tmp_nObs[i] = logitInv(F77_NAME(ddot)(&pDet, &Xp[i], &nObs, alpha, &inc) +
 			             alphaStarObs[i], zero, one);
-              logPostAlphaCurr += dbinom(y[i], N[NLongIndx[i]], tmp_nObs[i], 1);	     
+              logPostAlphaCurr += dbinom(y[i], N[NLongIndx[i]], tmp_nObs[i], 1);
 	    }
           }
           if (runif(0.0, 1.0) <= exp(logPostAlphaCand - logPostAlphaCurr)) {
@@ -406,18 +407,18 @@ extern "C" {
          *Update abundance random effects variance
          *******************************************************************/
         for (l = 0; l < pAbundRE; l++) {
-          tmp_0 = F77_NAME(ddot)(&nAbundRELong[l], &betaStar[betaStarStart[l]], &inc, &betaStar[betaStarStart[l]], &inc); 
-          tmp_0 *= 0.5; 
-          sigmaSqMu[l] = rigamma(sigmaSqMuA[l] + nAbundRELong[l] / 2.0, sigmaSqMuB[l] + tmp_0); 
+          tmp_0 = F77_NAME(ddot)(&nAbundRELong[l], &betaStar[betaStarStart[l]], &inc, &betaStar[betaStarStart[l]], &inc);
+          tmp_0 *= 0.5;
+          sigmaSqMu[l] = rigamma(sigmaSqMuA[l] + nAbundRELong[l] / 2.0, sigmaSqMuB[l] + tmp_0);
         }
 
         /********************************************************************
          *Update detection  random effects variance
          *******************************************************************/
         for (l = 0; l < pDetRE; l++) {
-          tmp_0 = F77_NAME(ddot)(&nDetRELong[l], &alphaStar[alphaStarStart[l]], &inc, &alphaStar[alphaStarStart[l]], &inc); 
-          tmp_0 *= 0.5; 
-          sigmaSqP[l] = rigamma(sigmaSqPA[l] + nDetRELong[l] / 2.0, sigmaSqPB[l] + tmp_0); 
+          tmp_0 = F77_NAME(ddot)(&nDetRELong[l], &alphaStar[alphaStarStart[l]], &inc, &alphaStar[alphaStarStart[l]], &inc);
+          tmp_0 *= 0.5;
+          sigmaSqP[l] = rigamma(sigmaSqPA[l] + nDetRELong[l] / 2.0, sigmaSqPB[l] + tmp_0);
         }
 
         /********************************************************************
@@ -426,20 +427,20 @@ extern "C" {
         if (pAbundRE > 0) {
           for (l = 0; l < nAbundRE; l++) {
 	    betaStarCand[l] = rnorm(betaStar[l], exp(tuning[betaStarAMCMCIndx + l]));
-            logPostBetaStarCand[l] = dnorm(betaStarCand[l], 0.0, 
+            logPostBetaStarCand[l] = dnorm(betaStarCand[l], 0.0,
 			                   sqrt(sigmaSqMu[betaStarIndx[l]]), 1);
-            logPostBetaStarCurr[l] = dnorm(betaStar[l], 0.0, 
+            logPostBetaStarCurr[l] = dnorm(betaStar[l], 0.0,
 			                   sqrt(sigmaSqMu[betaStarIndx[l]]), 1);
 	    for (j = 0; j < J; j++) {
               if (XRE[betaStarIndx[l] * J + j] == betaLevelIndx[l]) {
                 // Candidate
                 betaStarSitesCand[j] = 0.0;
                 for (ll = 0; ll < pAbundRE; ll++) {
-                  betaStarSitesCand[j] += betaStarCand[which(XRE[ll * J + j], 
-				                         betaLevelIndx, nAbundRE)] * 
+                  betaStarSitesCand[j] += betaStarCand[which(XRE[ll * J + j],
+				                         betaLevelIndx, nAbundRE)] *
 	                              XRandom[ll * J + j];
                 }
-                tmp_J[j] = exp(F77_NAME(ddot)(&pAbund, &X[j], &J, beta, &inc) + 
+                tmp_J[j] = exp(F77_NAME(ddot)(&pAbund, &X[j], &J, beta, &inc) +
 				  betaStarSitesCand[j]);
                 if (family == 1) {
 		  logPostBetaStarCand[l] += nb_logpost(kappa, N[j], tmp_J[j], offset[j]);
@@ -449,11 +450,11 @@ extern "C" {
 		// Current
                 betaStarSites[j] = 0.0;
                 for (ll = 0; ll < pAbundRE; ll++) {
-                  betaStarSites[j] += betaStar[which(XRE[ll * J + j], 
-				               betaLevelIndx, nAbundRE)] * 
+                  betaStarSites[j] += betaStar[which(XRE[ll * J + j],
+				               betaLevelIndx, nAbundRE)] *
 	                              XRandom[ll * J + j];
                 }
-                tmp_J[j] = exp(F77_NAME(ddot)(&pAbund, &X[j], &J, beta, &inc) + 
+                tmp_J[j] = exp(F77_NAME(ddot)(&pAbund, &X[j], &J, beta, &inc) +
 				  betaStarSites[j]);
                 if (family == 1) {
 		  logPostBetaStarCurr[l] += nb_logpost(kappa, N[j], tmp_J[j], offset[j]);
@@ -479,32 +480,32 @@ extern "C" {
         if (pDetRE > 0) {
           for (l = 0; l < nDetRE; l++) {
 	    alphaStarCand[l] = rnorm(alphaStar[l], exp(tuning[alphaStarAMCMCIndx + l]));
-            logPostAlphaStarCand[l] = dnorm(alphaStarCand[l], 0.0, 
+            logPostAlphaStarCand[l] = dnorm(alphaStarCand[l], 0.0,
 			                   sqrt(sigmaSqP[alphaStarIndx[l]]), 1);
-            logPostAlphaStarCurr[l] = dnorm(alphaStar[l], 0.0, 
+            logPostAlphaStarCurr[l] = dnorm(alphaStar[l], 0.0,
 			                   sqrt(sigmaSqP[alphaStarIndx[l]]), 1);
 	    for (i = 0; i < nObs; i++) {
               if ((N[NLongIndx[i]] > 0) && (XpRE[alphaStarIndx[l] * nObs + i] == alphaLevelIndx[l])) {
                 // Candidate
                 alphaStarObsCand[i] = 0.0;
                 for (ll = 0; ll < pDetRE; ll++) {
-                  alphaStarObsCand[i] += alphaStarCand[which(XpRE[ll * nObs + i], 
-				                         alphaLevelIndx, nDetRE)] * 
+                  alphaStarObsCand[i] += alphaStarCand[which(XpRE[ll * nObs + i],
+				                         alphaLevelIndx, nDetRE)] *
 	                              XpRandom[ll * nObs + i];
                 }
-                tmp_nObs[i] = logitInv(F77_NAME(ddot)(&pDet, &Xp[i], &nObs, alpha, &inc) + 
+                tmp_nObs[i] = logitInv(F77_NAME(ddot)(&pDet, &Xp[i], &nObs, alpha, &inc) +
 			               alphaStarObsCand[i], zero, one);
-                logPostAlphaStarCand[l] += dbinom(y[i], N[NLongIndx[i]], tmp_nObs[i], 1);	     
+                logPostAlphaStarCand[l] += dbinom(y[i], N[NLongIndx[i]], tmp_nObs[i], 1);
 		// Current
                 alphaStarObs[i] = 0.0;
                 for (ll = 0; ll < pDetRE; ll++) {
-                  alphaStarObs[i] += alphaStar[which(XpRE[ll * nObs + i], 
-				               alphaLevelIndx, nDetRE)] * 
+                  alphaStarObs[i] += alphaStar[which(XpRE[ll * nObs + i],
+				               alphaLevelIndx, nDetRE)] *
 	                              XpRandom[ll * nObs + i];
                 }
-                tmp_nObs[i] = logitInv(F77_NAME(ddot)(&pDet, &Xp[i], &nObs, alpha, &inc) + 
+                tmp_nObs[i] = logitInv(F77_NAME(ddot)(&pDet, &Xp[i], &nObs, alpha, &inc) +
 			               alphaStarObs[i], zero, one);
-                logPostAlphaStarCurr[l] += dbinom(y[i], N[NLongIndx[i]], tmp_nObs[i], 1);	     
+                logPostAlphaStarCurr[l] += dbinom(y[i], N[NLongIndx[i]], tmp_nObs[i], 1);
 	      }
 	    }
 	    if (runif (0.0, 1.0) <= exp(logPostAlphaStarCand[l] - logPostAlphaStarCurr[l])) {
@@ -517,17 +518,17 @@ extern "C" {
 	    }
 	  }
 	}
-        
+
         /********************************************************************
          *Update kappa (the NB size parameter)
          *******************************************************************/
 	if (family == 1) {
-          kappaCand = logitInv(rnorm(logit(kappa, kappaA, kappaB), exp(tuning[kappaAMCMCIndx])), 
+          kappaCand = logitInv(rnorm(logit(kappa, kappaA, kappaB), exp(tuning[kappaAMCMCIndx])),
 			       kappaA, kappaB);
 	  logPostKappaCurr = 0.0;
 	  logPostKappaCand = 0.0;
 	  for (j = 0; j < J; j++) {
-            mu[j] = exp(F77_NAME(ddot)(&pAbund, &X[j], &J, beta, &inc) + 
+            mu[j] = exp(F77_NAME(ddot)(&pAbund, &X[j], &J, beta, &inc) +
                         betaStarSites[j]);
             logPostKappaCurr += nb_logpost(kappa, N[j], mu[j], offset[j]);
 	    logPostKappaCand += nb_logpost(kappaCand, N[j], mu[j], offset[j]);
@@ -542,7 +543,7 @@ extern "C" {
 	}
 
         /********************************************************************
-         *Update Latent Abundance 
+         *Update Latent Abundance
          *******************************************************************/
 	zeros(logPostCurrN, J);
 	zeros(logPostCandN, J);
@@ -551,13 +552,13 @@ extern "C" {
           NCand[j] = rpois(N[j] + epsilonN);
 	  // Only calculate if Poisson since its already calculated in kappa update
 	  if (family == 0) {
-            mu[j] = exp(F77_NAME(ddot)(&pAbund, &X[j], &J, beta, &inc) + 
+            mu[j] = exp(F77_NAME(ddot)(&pAbund, &X[j], &J, beta, &inc) +
                         betaStarSites[j]);
 	  }
 	}
 	// Likelihood contribution to Metropolis ratios
 	for (i = 0; i < nObs; i++) {
-          detProb[i] = logitInv(F77_NAME(ddot)(&pDet, &Xp[i], &nObs, alpha, &inc) + 
+          detProb[i] = logitInv(F77_NAME(ddot)(&pDet, &Xp[i], &nObs, alpha, &inc) +
 	        	        alphaStarObs[i], zero, one);
           logPostCurrN[NLongIndx[i]] += dbinom(y[i], N[NLongIndx[i]], detProb[i], 1);
 	  logPostCandN[NLongIndx[i]] += dbinom(y[i], NCand[NLongIndx[i]], detProb[i], 1);
@@ -595,39 +596,39 @@ extern "C" {
          *Save samples
          *******************************************************************/
         if (g >= nBurn) {
-          thinIndx++; 
+          thinIndx++;
           if (thinIndx == nThin) {
             F77_NAME(dcopy)(&pAbund, beta, &inc, &REAL(betaSamples_r)[sPost*pAbund], &inc);
             F77_NAME(dcopy)(&pDet, alpha, &inc, &REAL(alphaSamples_r)[sPost*pDet], &inc);
 	    if (family == 1) {
 	      REAL(kappaSamples_r)[sPost] = kappa;
 	    }
-            F77_NAME(dcopy)(&J, mu, &inc, &REAL(muSamples_r)[sPost*J], &inc); 
-            F77_NAME(dcopy)(&J, N, &inc, &REAL(NSamples_r)[sPost*J], &inc); 
+            F77_NAME(dcopy)(&J, mu, &inc, &REAL(muSamples_r)[sPost*J], &inc);
+            F77_NAME(dcopy)(&J, N, &inc, &REAL(NSamples_r)[sPost*J], &inc);
             if (pAbundRE > 0) {
-              F77_NAME(dcopy)(&pAbundRE, sigmaSqMu, &inc, 
+              F77_NAME(dcopy)(&pAbundRE, sigmaSqMu, &inc,
           		    &REAL(sigmaSqMuSamples_r)[sPost*pAbundRE], &inc);
-              F77_NAME(dcopy)(&nAbundRE, betaStar, &inc, 
+              F77_NAME(dcopy)(&nAbundRE, betaStar, &inc,
           		    &REAL(betaStarSamples_r)[sPost*nAbundRE], &inc);
             }
             if (pDetRE > 0) {
-              F77_NAME(dcopy)(&pDetRE, sigmaSqP, &inc, 
+              F77_NAME(dcopy)(&pDetRE, sigmaSqP, &inc,
                   	      &REAL(sigmaSqPSamples_r)[sPost*pDetRE], &inc);
-              F77_NAME(dcopy)(&nDetRE, alphaStar, &inc, 
+              F77_NAME(dcopy)(&nDetRE, alphaStar, &inc,
                   	      &REAL(alphaStarSamples_r)[sPost*nDetRE], &inc);
             }
-            sPost++; 
-            thinIndx = 0; 
+            sPost++;
+            thinIndx = 0;
           }
         }
         R_CheckUserInterrupt();
       } // t (end batch)
       /********************************************************************
-       *Adjust tuning 
+       *Adjust tuning
        *******************************************************************/
       for (j = 0; j < nAMCMC; j++) {
-        REAL(acceptSamples_r)[s * nAMCMC + j] = accept[j]/batchLength; 
-        REAL(tuningSamples_r)[s * nAMCMC + j] = tuning[j]; 
+        REAL(acceptSamples_r)[s * nAMCMC + j] = accept[j]/batchLength;
+        REAL(tuningSamples_r)[s * nAMCMC + j] = tuning[j];
         if (accept[j] / batchLength > acceptRate) {
           tuning[j] += std::min(0.01, 1.0/sqrt(static_cast<double>(s)));
         } else{
@@ -637,12 +638,12 @@ extern "C" {
       }
 
       /********************************************************************
-       *Report 
+       *Report
        *******************************************************************/
       if (verbose) {
         if (status == nReport) {
           Rprintf("Batch: %i of %i, %3.2f%%\n", s, nBatch, 100.0*s/nBatch);
-          Rprintf("\tParameter\tAcceptance\tTuning\n");	  
+          Rprintf("\tParameter\tAcceptance\tTuning\n");
           for (j = 0; j < pAbund; j++) {
             Rprintf("\tbeta[%i]\t\t%3.1f\t\t%1.5f\n", j + 1, 100.0*REAL(acceptSamples_r)[s * nAMCMC + betaAMCMCIndx + j], exp(tuning[betaAMCMCIndx + j]));
           }
@@ -658,8 +659,8 @@ extern "C" {
           #endif
           status = 0;
         }
-      } 
-      status++;        
+      }
+      status++;
 
     } // all batches
     if (verbose) {
@@ -670,7 +671,7 @@ extern "C" {
     SEXP result_r, resultName_r;
     int nResultListObjs = 5;
     if (pDetRE > 0) {
-      nResultListObjs += 2; 
+      nResultListObjs += 2;
     }
     if (pAbundRE > 0) {
       nResultListObjs += 2;
@@ -679,17 +680,17 @@ extern "C" {
       nResultListObjs += 1;
     }
 
-    PROTECT(result_r = allocVector(VECSXP, nResultListObjs)); nProtect++;
-    PROTECT(resultName_r = allocVector(VECSXP, nResultListObjs)); nProtect++;
+    PROTECT(result_r = Rf_allocVector(VECSXP, nResultListObjs)); nProtect++;
+    PROTECT(resultName_r = Rf_allocVector(VECSXP, nResultListObjs)); nProtect++;
 
     // Setting the components of the output list.
     SET_VECTOR_ELT(result_r, 0, betaSamples_r);
     SET_VECTOR_ELT(result_r, 1, alphaSamples_r);
-    SET_VECTOR_ELT(result_r, 2, NSamples_r); 
+    SET_VECTOR_ELT(result_r, 2, NSamples_r);
     SET_VECTOR_ELT(result_r, 3, muSamples_r);
     SET_VECTOR_ELT(result_r, 4, tuningSamples_r);
     if (pDetRE > 0) {
-      tmp_0 = 5; // Needed to make tracking kappa easier. 
+      tmp_0 = 5; // Needed to make tracking kappa easier.
       SET_VECTOR_ELT(result_r, 5, sigmaSqPSamples_r);
       SET_VECTOR_ELT(result_r, 6, alphaStarSamples_r);
     }
@@ -707,31 +708,31 @@ extern "C" {
         tmp_02 = tmp_0 + 2;
       } else {
         tmp_02 = 5;
-      }  
+      }
       SET_VECTOR_ELT(result_r, tmp_02, kappaSamples_r);
     }
 
-    SET_VECTOR_ELT(resultName_r, 0, mkChar("beta.samples")); 
-    SET_VECTOR_ELT(resultName_r, 1, mkChar("alpha.samples")); 
-    SET_VECTOR_ELT(resultName_r, 2, mkChar("N.samples")); 
-    SET_VECTOR_ELT(resultName_r, 3, mkChar("mu.samples"));
-    SET_VECTOR_ELT(resultName_r, 4, mkChar("tuning.samples"));
+    SET_VECTOR_ELT(resultName_r, 0, Rf_mkChar("beta.samples"));
+    SET_VECTOR_ELT(resultName_r, 1, Rf_mkChar("alpha.samples"));
+    SET_VECTOR_ELT(resultName_r, 2, Rf_mkChar("N.samples"));
+    SET_VECTOR_ELT(resultName_r, 3, Rf_mkChar("mu.samples"));
+    SET_VECTOR_ELT(resultName_r, 4, Rf_mkChar("tuning.samples"));
     if (pDetRE > 0) {
-      SET_VECTOR_ELT(resultName_r, 5, mkChar("sigma.sq.p.samples")); 
-      SET_VECTOR_ELT(resultName_r, 6, mkChar("alpha.star.samples")); 
+      SET_VECTOR_ELT(resultName_r, 5, Rf_mkChar("sigma.sq.p.samples"));
+      SET_VECTOR_ELT(resultName_r, 6, Rf_mkChar("alpha.star.samples"));
     }
     if (pAbundRE > 0) {
-      SET_VECTOR_ELT(resultName_r, tmp_0, mkChar("sigma.sq.mu.samples")); 
-      SET_VECTOR_ELT(resultName_r, tmp_0 + 1, mkChar("beta.star.samples")); 
+      SET_VECTOR_ELT(resultName_r, tmp_0, Rf_mkChar("sigma.sq.mu.samples"));
+      SET_VECTOR_ELT(resultName_r, tmp_0 + 1, Rf_mkChar("beta.star.samples"));
     }
     if (family == 1) {
-      SET_VECTOR_ELT(resultName_r, tmp_02, mkChar("kappa.samples")); 
+      SET_VECTOR_ELT(resultName_r, tmp_02, Rf_mkChar("kappa.samples"));
     }
-   
-    namesgets(result_r, resultName_r);
-    
+
+    Rf_namesgets(result_r, resultName_r);
+
     UNPROTECT(nProtect);
-    
+
     return(result_r);
   }
 }
