@@ -7,6 +7,7 @@
 #include <omp.h>
 #endif
 
+#define R_NO_REMAP
 #include <R.h>
 #include <Rmath.h>
 #include <Rinternals.h>
@@ -19,30 +20,30 @@
 
 extern "C" {
   SEXP abund(SEXP y_r, SEXP X_r, SEXP XRE_r, SEXP XRandom_r,
-             SEXP consts_r,SEXP nAbundRELong_r, 
-             SEXP betaStarting_r, SEXP kappaStarting_r, 
-	     SEXP sigmaSqMuStarting_r, SEXP betaStarStarting_r, 
-             SEXP siteIndx_r, SEXP betaStarIndx_r, SEXP betaLevelIndx_r, 
-	     SEXP muBeta_r, SEXP SigmaBeta_r, 
-	     SEXP kappaA_r, SEXP kappaB_r, SEXP sigmaSqMuA_r, 
-	     SEXP sigmaSqMuB_r, SEXP tuning_r,
-	     SEXP nBatch_r, SEXP batchLength_r, SEXP acceptRate_r, SEXP nThreads_r, 
+             SEXP consts_r,SEXP nAbundRELong_r,
+             SEXP betaStarting_r, SEXP kappaStarting_r,
+             SEXP sigmaSqMuStarting_r, SEXP betaStarStarting_r,
+             SEXP siteIndx_r, SEXP betaStarIndx_r, SEXP betaLevelIndx_r,
+             SEXP muBeta_r, SEXP SigmaBeta_r,
+             SEXP kappaA_r, SEXP kappaB_r, SEXP sigmaSqMuA_r,
+             SEXP sigmaSqMuB_r, SEXP tuning_r,
+             SEXP nBatch_r, SEXP batchLength_r, SEXP acceptRate_r, SEXP nThreads_r,
              SEXP verbose_r, SEXP nReport_r, SEXP samplesInfo_r,
-	     SEXP chainInfo_r, SEXP family_r, SEXP offset_r){
-   
+             SEXP chainInfo_r, SEXP family_r, SEXP offset_r){
+
     /**********************************************************************
      * Initial constants
      * *******************************************************************/
     int g, t, j, s, l, k, ll, nProtect=0;
     const int inc = 1;
-    
+
     /**********************************************************************
      * Get Inputs
      * *******************************************************************/
     double *y = REAL(y_r);
     double *X = REAL(X_r);
     double *offset = REAL(offset_r);
-    int *XRE = INTEGER(XRE_r); 
+    int *XRE = INTEGER(XRE_r);
     // Load constants
     int J = INTEGER(consts_r)[0];
     double *XRandom = REAL(XRandom_r);
@@ -51,24 +52,24 @@ extern "C" {
     int pAbundRE = INTEGER(consts_r)[3];
     int nAbundRE = INTEGER(consts_r)[4];
     int saveFitted = INTEGER(consts_r)[5];
-    int ppAbund = pAbund * pAbund; 
-    double *muBeta = (double *) R_alloc(pAbund, sizeof(double));   
+    int ppAbund = pAbund * pAbund;
+    double *muBeta = (double *) R_alloc(pAbund, sizeof(double));
     F77_NAME(dcopy)(&pAbund, REAL(muBeta_r), &inc, muBeta, &inc);
     double *SigmaBeta = (double *) R_alloc(ppAbund, sizeof(double));
     F77_NAME(dcopy)(&ppAbund, REAL(SigmaBeta_r), &inc, SigmaBeta, &inc);
     double kappaA = REAL(kappaA_r)[0];
     double kappaB = REAL(kappaB_r)[0];
-    double *sigmaSqMuA = REAL(sigmaSqMuA_r); 
-    double *sigmaSqMuB = REAL(sigmaSqMuB_r); 
-    int *nAbundRELong = INTEGER(nAbundRELong_r); 
-    int *betaStarIndx = INTEGER(betaStarIndx_r); 
+    double *sigmaSqMuA = REAL(sigmaSqMuA_r);
+    double *sigmaSqMuB = REAL(sigmaSqMuB_r);
+    int *nAbundRELong = INTEGER(nAbundRELong_r);
+    int *betaStarIndx = INTEGER(betaStarIndx_r);
     int *betaLevelIndx = INTEGER(betaLevelIndx_r);
-    int nBatch = INTEGER(nBatch_r)[0]; 
-    int batchLength = INTEGER(batchLength_r)[0]; 
-    int nSamples = nBatch * batchLength; 
-    int nBurn = INTEGER(samplesInfo_r)[0]; 
+    int nBatch = INTEGER(nBatch_r)[0];
+    int batchLength = INTEGER(batchLength_r)[0];
+    int nSamples = nBatch * batchLength;
+    int nBurn = INTEGER(samplesInfo_r)[0];
     int nThin = INTEGER(samplesInfo_r)[1];
-    int nPost = INTEGER(samplesInfo_r)[2]; 
+    int nPost = INTEGER(samplesInfo_r)[2];
     int currChain = INTEGER(chainInfo_r)[0];
     double acceptRate = REAL(acceptRate_r)[0];
     double* tuning = REAL(tuning_r);
@@ -76,9 +77,9 @@ extern "C" {
     int nThreads = INTEGER(nThreads_r)[0];
     int verbose = INTEGER(verbose_r)[0];
     int nReport = INTEGER(nReport_r)[0];
-    int status = 0; 
+    int status = 0;
     int thinIndx = 0;
-    int sPost = 0;  
+    int sPost = 0;
     // NB = 1, Poisson = 0;
     int family = INTEGER(family_r)[0];
 
@@ -86,13 +87,13 @@ extern "C" {
     omp_set_num_threads(nThreads);
 #else
     if(nThreads > 1){
-      warning("n.omp.threads > 1, but source not compiled with OpenMP support.");
+      Rf_warning("n.omp.threads > 1, but source not compiled with OpenMP support.");
       nThreads = 1;
     }
 #endif
-    
+
     /**********************************************************************
-     * Print Information 
+     * Print Information
      * *******************************************************************/
     if(verbose){
       if (currChain == 1) {
@@ -105,10 +106,10 @@ extern "C" {
           Rprintf("Poisson abundance model fit with %i sites.\n\n", J);
 	}
         Rprintf("Samples per Chain: %i (%i batches of length %i)\n", nSamples, nBatch, batchLength);
-        Rprintf("Burn-in: %i \n", nBurn); 
-        Rprintf("Thinning Rate: %i \n", nThin); 
+        Rprintf("Burn-in: %i \n", nBurn);
+        Rprintf("Thinning Rate: %i \n", nThin);
         Rprintf("Number of Chains: %i \n", nChain);
-        Rprintf("Total Posterior Samples: %i \n\n", nPost * nChain); 
+        Rprintf("Total Posterior Samples: %i \n\n", nPost * nChain);
 #ifdef _OPENMP
         Rprintf("Source compiled with OpenMP support and model fit using %i thread(s).\n\n", nThreads);
 #else
@@ -128,17 +129,17 @@ extern "C" {
     /**********************************************************************
      * Parameters
      * *******************************************************************/
-    // Abundance Covariates 
-    double *beta = (double *) R_alloc(pAbund, sizeof(double));   
+    // Abundance Covariates
+    double *beta = (double *) R_alloc(pAbund, sizeof(double));
     F77_NAME(dcopy)(&pAbund, REAL(betaStarting_r), &inc, beta, &inc);
     // Abundance random effect variances
-    double *sigmaSqMu = (double *) R_alloc(pAbundRE, sizeof(double)); 
-    F77_NAME(dcopy)(&pAbundRE, REAL(sigmaSqMuStarting_r), &inc, sigmaSqMu, &inc); 
+    double *sigmaSqMu = (double *) R_alloc(pAbundRE, sizeof(double));
+    F77_NAME(dcopy)(&pAbundRE, REAL(sigmaSqMuStarting_r), &inc, sigmaSqMu, &inc);
     // Overdispersion parameter for NB;
     double kappa = REAL(kappaStarting_r)[0];
     // Latent random effects
-    double *betaStar = (double *) R_alloc(nAbundRE, sizeof(double)); 
-    F77_NAME(dcopy)(&nAbundRE, REAL(betaStarStarting_r), &inc, betaStar, &inc); 
+    double *betaStar = (double *) R_alloc(nAbundRE, sizeof(double));
+    F77_NAME(dcopy)(&nAbundRE, REAL(betaStarStarting_r), &inc, betaStar, &inc);
     // Abundance fitted values
     double *yRep = (double *) R_alloc(nObs, sizeof(double)); zeros(yRep, nObs);
 
@@ -146,45 +147,45 @@ extern "C" {
      * Return Stuff
      * *******************************************************************/
     SEXP betaSamples_r;
-    PROTECT(betaSamples_r = allocMatrix(REALSXP, pAbund, nPost)); nProtect++;
+    PROTECT(betaSamples_r = Rf_allocMatrix(REALSXP, pAbund, nPost)); nProtect++;
     zeros(REAL(betaSamples_r), pAbund * nPost);
-    SEXP yRepSamples_r; 
-    SEXP muSamples_r; 
+    SEXP yRepSamples_r;
+    SEXP muSamples_r;
     SEXP likeSamples_r;
     if (saveFitted == 1) {
-      PROTECT(yRepSamples_r = allocMatrix(REALSXP, nObs, nPost)); nProtect++; 
+      PROTECT(yRepSamples_r = Rf_allocMatrix(REALSXP, nObs, nPost)); nProtect++;
       zeros(REAL(yRepSamples_r), nObs * nPost);
-      PROTECT(muSamples_r = allocMatrix(REALSXP, nObs, nPost)); nProtect++; 
+      PROTECT(muSamples_r = Rf_allocMatrix(REALSXP, nObs, nPost)); nProtect++;
       zeros(REAL(muSamples_r), nObs * nPost);
-      PROTECT(likeSamples_r = allocMatrix(REALSXP, nObs, nPost)); nProtect++;
+      PROTECT(likeSamples_r = Rf_allocMatrix(REALSXP, nObs, nPost)); nProtect++;
       zeros(REAL(likeSamples_r), nObs * nPost);
     }
     SEXP kappaSamples_r;
     if (family == 1) {
-      PROTECT(kappaSamples_r = allocMatrix(REALSXP, inc, nPost)); nProtect++;
+      PROTECT(kappaSamples_r = Rf_allocMatrix(REALSXP, inc, nPost)); nProtect++;
       zeros(REAL(kappaSamples_r), nPost);
     }
     // Abundance random effects
-    SEXP sigmaSqMuSamples_r; 
-    SEXP betaStarSamples_r; 
+    SEXP sigmaSqMuSamples_r;
+    SEXP betaStarSamples_r;
     if (pAbundRE > 0) {
-      PROTECT(sigmaSqMuSamples_r = allocMatrix(REALSXP, pAbundRE, nPost)); nProtect++;
+      PROTECT(sigmaSqMuSamples_r = Rf_allocMatrix(REALSXP, pAbundRE, nPost)); nProtect++;
       zeros(REAL(sigmaSqMuSamples_r), pAbundRE * nPost);
-      PROTECT(betaStarSamples_r = allocMatrix(REALSXP, nAbundRE, nPost)); nProtect++;
+      PROTECT(betaStarSamples_r = Rf_allocMatrix(REALSXP, nAbundRE, nPost)); nProtect++;
       zeros(REAL(betaStarSamples_r), nAbundRE * nPost);
     }
-    
+
     /********************************************************************
       Some constants and temporary variables to be used later
     ********************************************************************/
     int nObspAbundRE = nObs * pAbundRE;
-    double tmp_0; 
-    double *tmp_nObs = (double *) R_alloc(nObs, sizeof(double)); 
-   
+    double tmp_0;
+    double *tmp_nObs = (double *) R_alloc(nObs, sizeof(double));
+
     // For latent abundance and WAIC
     double *like = (double *) R_alloc(nObs, sizeof(double)); zeros(like, nObs);
-    double *mu = (double *) R_alloc(nObs, sizeof(double)); 
-    zeros(mu, nObs); 
+    double *mu = (double *) R_alloc(nObs, sizeof(double));
+    zeros(mu, nObs);
 
     /********************************************************************
       Set up MH stuff
@@ -208,33 +209,33 @@ extern "C" {
     }
     int betaAMCMCIndx = 0;
     int betaStarAMCMCIndx = betaAMCMCIndx + pAbund;
-    int kappaAMCMCIndx = betaStarAMCMCIndx + nAbundRE; // nAbundRE will be 0 if no REs. 
+    int kappaAMCMCIndx = betaStarAMCMCIndx + nAbundRE; // nAbundRE will be 0 if no REs.
     double *accept = (double *) R_alloc(nAMCMC, sizeof(double)); zeros(accept, nAMCMC);
-    // Set the initial candidate values for everything to the inital values. 
-    double *betaCand = (double *) R_alloc(pAbund, sizeof(double)); 
+    // Set the initial candidate values for everything to the inital values.
+    double *betaCand = (double *) R_alloc(pAbund, sizeof(double));
     for (j = 0; j < pAbund; j++) {
       betaCand[j] = beta[j];
-    } 
+    }
     double *betaStarCand = (double *) R_alloc(nAbundRE, sizeof(double));
     for (j = 0; j < nAbundRE; j++) {
       betaStarCand[j] = betaStar[j];
     }
     double kappaCand = 0.0;
     kappaCand = kappa;
-    SEXP acceptSamples_r; 
-    PROTECT(acceptSamples_r = allocMatrix(REALSXP, nAMCMC, nBatch)); nProtect++; 
+    SEXP acceptSamples_r;
+    PROTECT(acceptSamples_r = Rf_allocMatrix(REALSXP, nAMCMC, nBatch)); nProtect++;
     zeros(REAL(acceptSamples_r), nAMCMC * nBatch);
-    SEXP tuningSamples_r; 
-    PROTECT(tuningSamples_r = allocMatrix(REALSXP, nAMCMC, nBatch)); nProtect++; 
+    SEXP tuningSamples_r;
+    PROTECT(tuningSamples_r = Rf_allocMatrix(REALSXP, nAMCMC, nBatch)); nProtect++;
     zeros(REAL(tuningSamples_r), nAMCMC * nBatch);
 
     /**********************************************************************
      * Prep for random effects
      * *******************************************************************/
     // Site-level sums of the abundance random effects
-    double *betaStarSites = (double *) R_alloc(nObs, sizeof(double)); 
-    zeros(betaStarSites, nObs); 
-    double *betaStarSitesCand = (double *) R_alloc(nObs, sizeof(double)); 
+    double *betaStarSites = (double *) R_alloc(nObs, sizeof(double));
+    zeros(betaStarSites, nObs);
+    double *betaStarSitesCand = (double *) R_alloc(nObs, sizeof(double));
     int *betaStarLongIndx = (int *) R_alloc(nObspAbundRE, sizeof(int));
     // Initial sums
     for (j = 0; j < nObs; j++) {
@@ -245,14 +246,14 @@ extern "C" {
       betaStarSitesCand[j] = betaStarSites[j];
     }
     // Starting index for abundance random effects
-    int *betaStarStart = (int *) R_alloc(pAbundRE, sizeof(int)); 
+    int *betaStarStart = (int *) R_alloc(pAbundRE, sizeof(int));
     for (l = 0; l < pAbundRE; l++) {
-      betaStarStart[l] = which(l, betaStarIndx, nAbundRE); 
+      betaStarStart[l] = which(l, betaStarIndx, nAbundRE);
     }
 
     logPostBetaCurr = R_NegInf;
 
-    GetRNGstate(); 
+    GetRNGstate();
 
     for (s = 0, g = 0; s < nBatch; s++) {
       for (t = 0; t < batchLength; t++, g++) {
@@ -287,14 +288,14 @@ extern "C" {
             betaCand[k] = beta[k];
 	  }
         }
-        
+
         /********************************************************************
          *Update abundance random effects variance
          *******************************************************************/
         for (l = 0; l < pAbundRE; l++) {
-          tmp_0 = F77_NAME(ddot)(&nAbundRELong[l], &betaStar[betaStarStart[l]], &inc, &betaStar[betaStarStart[l]], &inc); 
-          tmp_0 *= 0.5; 
-          sigmaSqMu[l] = rigamma(sigmaSqMuA[l] + nAbundRELong[l] / 2.0, sigmaSqMuB[l] + tmp_0); 
+          tmp_0 = F77_NAME(ddot)(&nAbundRELong[l], &betaStar[betaStarStart[l]], &inc, &betaStar[betaStarStart[l]], &inc);
+          tmp_0 *= 0.5;
+          sigmaSqMu[l] = rigamma(sigmaSqMuA[l] + nAbundRELong[l] / 2.0, sigmaSqMuB[l] + tmp_0);
         }
 
         /********************************************************************
@@ -303,19 +304,19 @@ extern "C" {
         if (pAbundRE > 0) {
           for (l = 0; l < nAbundRE; l++) {
 	    betaStarCand[l] = rnorm(betaStar[l], exp(tuning[betaStarAMCMCIndx + l]));
-            logPostBetaStarCand[l] = dnorm(betaStarCand[l], 0.0, 
+            logPostBetaStarCand[l] = dnorm(betaStarCand[l], 0.0,
 			                   sqrt(sigmaSqMu[betaStarIndx[l]]), 1);
-            logPostBetaStarCurr[l] = dnorm(betaStar[l], 0.0, 
+            logPostBetaStarCurr[l] = dnorm(betaStar[l], 0.0,
 			                   sqrt(sigmaSqMu[betaStarIndx[l]]), 1);
 	    for (j = 0; j < nObs; j++) {
               if (XRE[betaStarIndx[l] * nObs + j] == betaLevelIndx[l]) {
                 // Candidate
                 betaStarSitesCand[j] = 0.0;
                 for (ll = 0; ll < pAbundRE; ll++) {
-                  betaStarSitesCand[j] += betaStarCand[betaStarLongIndx[ll * nObs + j]] * 
+                  betaStarSitesCand[j] += betaStarCand[betaStarLongIndx[ll * nObs + j]] *
 	                              XRandom[ll * nObs + j];
                 }
-                tmp_nObs[j] = exp(F77_NAME(ddot)(&pAbund, &X[j], &nObs, beta, &inc) + 
+                tmp_nObs[j] = exp(F77_NAME(ddot)(&pAbund, &X[j], &nObs, beta, &inc) +
 				  betaStarSitesCand[j]);
                 if (family == 1) {
 		  logPostBetaStarCand[l] += dnbinom_mu(y[j], kappa, tmp_nObs[j] * offset[j], 1);
@@ -325,10 +326,10 @@ extern "C" {
 		// Current
                 betaStarSites[j] = 0.0;
                 for (ll = 0; ll < pAbundRE; ll++) {
-                  betaStarSites[j] += betaStar[betaStarLongIndx[ll * nObs + j]] * 
+                  betaStarSites[j] += betaStar[betaStarLongIndx[ll * nObs + j]] *
 	                              XRandom[ll * nObs + j];
                 }
-                tmp_nObs[j] = exp(F77_NAME(ddot)(&pAbund, &X[j], &nObs, beta, &inc) + 
+                tmp_nObs[j] = exp(F77_NAME(ddot)(&pAbund, &X[j], &nObs, beta, &inc) +
 				  betaStarSites[j]);
                 if (family == 1) {
 		  logPostBetaStarCurr[l] += dnbinom_mu(y[j], kappa, tmp_nObs[j] * offset[j], 1);
@@ -352,12 +353,12 @@ extern "C" {
          *Update kappa (the NB size parameter)
          *******************************************************************/
         if (family == 1) {
-          kappaCand = logitInv(rnorm(logit(kappa, kappaA, kappaB), exp(tuning[kappaAMCMCIndx])), 
+          kappaCand = logitInv(rnorm(logit(kappa, kappaA, kappaB), exp(tuning[kappaAMCMCIndx])),
 			       kappaA, kappaB);
 	  logPostKappaCurr = 0.0;
 	  logPostKappaCand = 0.0;
 	  for (j = 0; j < nObs; j++) {
-            mu[j] = exp(F77_NAME(ddot)(&pAbund, &X[j], &nObs, beta, &inc) + 
+            mu[j] = exp(F77_NAME(ddot)(&pAbund, &X[j], &nObs, beta, &inc) +
                         betaStarSites[j]);
             logPostKappaCurr += dnbinom_mu(y[j], kappa, mu[j] * offset[j], 1);
 	    logPostKappaCand += dnbinom_mu(y[j], kappaCand, mu[j] * offset[j], 1);
@@ -378,7 +379,7 @@ extern "C" {
           for (j = 0; j < nObs; j++) {
             // Only calculate if Poisson since it's already calculated in kappa update
 	    if (family == 0) {
-              mu[j] = exp(F77_NAME(ddot)(&pAbund, &X[j], &nObs, beta, &inc) + 
+              mu[j] = exp(F77_NAME(ddot)(&pAbund, &X[j], &nObs, beta, &inc) +
                           betaStarSites[j]);
               yRep[j] = rpois(mu[j] * offset[j]);
               like[j] = dpois(y[j], mu[j] * offset[j], 0);
@@ -393,36 +394,36 @@ extern "C" {
          *Save samples
          *******************************************************************/
         if (g >= nBurn) {
-          thinIndx++; 
+          thinIndx++;
           if (thinIndx == nThin) {
             F77_NAME(dcopy)(&pAbund, beta, &inc, &REAL(betaSamples_r)[sPost*pAbund], &inc);
 	    if (saveFitted == 1) {
-              F77_NAME(dcopy)(&nObs, yRep, &inc, &REAL(yRepSamples_r)[sPost*nObs], &inc); 
-              F77_NAME(dcopy)(&nObs, mu, &inc, &REAL(muSamples_r)[sPost*nObs], &inc); 
-              F77_NAME(dcopy)(&nObs, like, &inc, 
+              F77_NAME(dcopy)(&nObs, yRep, &inc, &REAL(yRepSamples_r)[sPost*nObs], &inc);
+              F77_NAME(dcopy)(&nObs, mu, &inc, &REAL(muSamples_r)[sPost*nObs], &inc);
+              F77_NAME(dcopy)(&nObs, like, &inc,
           		      &REAL(likeSamples_r)[sPost*nObs], &inc);
 	    }
 	    if (family == 1) {
 	      REAL(kappaSamples_r)[sPost] = kappa;
 	    }
             if (pAbundRE > 0) {
-              F77_NAME(dcopy)(&pAbundRE, sigmaSqMu, &inc, 
+              F77_NAME(dcopy)(&pAbundRE, sigmaSqMu, &inc,
           		    &REAL(sigmaSqMuSamples_r)[sPost*pAbundRE], &inc);
-              F77_NAME(dcopy)(&nAbundRE, betaStar, &inc, 
+              F77_NAME(dcopy)(&nAbundRE, betaStar, &inc,
           		    &REAL(betaStarSamples_r)[sPost*nAbundRE], &inc);
             }
-            sPost++; 
-            thinIndx = 0; 
+            sPost++;
+            thinIndx = 0;
           }
         }
         R_CheckUserInterrupt();
       } // t (end batch)
       /********************************************************************
-       *Adjust tuning 
+       *Adjust tuning
        *******************************************************************/
       for (j = 0; j < nAMCMC; j++) {
-        REAL(acceptSamples_r)[s * nAMCMC + j] = accept[j]/batchLength; 
-        REAL(tuningSamples_r)[s * nAMCMC + j] = tuning[j]; 
+        REAL(acceptSamples_r)[s * nAMCMC + j] = accept[j]/batchLength;
+        REAL(tuningSamples_r)[s * nAMCMC + j] = tuning[j];
         if (accept[j] / batchLength > acceptRate) {
           tuning[j] += std::min(0.01, 1.0/sqrt(static_cast<double>(s)));
         } else{
@@ -432,12 +433,12 @@ extern "C" {
       }
 
       /********************************************************************
-       *Report 
+       *Report
        *******************************************************************/
       if (verbose) {
         if (status == nReport) {
           Rprintf("Batch: %i of %i, %3.2f%%\n", s, nBatch, 100.0*s/nBatch);
-          Rprintf("\tParameter\tAcceptance\tTuning\n");	  
+          Rprintf("\tParameter\tAcceptance\tTuning\n");
           for (j = 0; j < pAbund; j++) {
             Rprintf("\tbeta[%i]\t\t%3.1f\t\t%1.5f\n", j + 1, 100.0*REAL(acceptSamples_r)[s * nAMCMC + betaAMCMCIndx + j], exp(tuning[betaAMCMCIndx + j]));
           }
@@ -450,8 +451,8 @@ extern "C" {
           #endif
           status = 0;
         }
-      } 
-      status++;        
+      }
+      status++;
 
     } // all batches
     if (verbose) {
@@ -468,13 +469,13 @@ extern "C" {
       nResultListObjs += 1;
     }
 
-    PROTECT(result_r = allocVector(VECSXP, nResultListObjs)); nProtect++;
-    PROTECT(resultName_r = allocVector(VECSXP, nResultListObjs)); nProtect++;
+    PROTECT(result_r = Rf_allocVector(VECSXP, nResultListObjs)); nProtect++;
+    PROTECT(resultName_r = Rf_allocVector(VECSXP, nResultListObjs)); nProtect++;
 
     // Setting the components of the output list.
     SET_VECTOR_ELT(result_r, 0, betaSamples_r);
     if (saveFitted == 1) {
-      SET_VECTOR_ELT(result_r, 1, yRepSamples_r); 
+      SET_VECTOR_ELT(result_r, 1, yRepSamples_r);
       SET_VECTOR_ELT(result_r, 2, muSamples_r);
       SET_VECTOR_ELT(result_r, 3, likeSamples_r);
     }
@@ -491,24 +492,24 @@ extern "C" {
       SET_VECTOR_ELT(result_r, tmp_0, kappaSamples_r);
     }
 
-    SET_VECTOR_ELT(resultName_r, 0, mkChar("beta.samples")); 
+    SET_VECTOR_ELT(resultName_r, 0, Rf_mkChar("beta.samples"));
     if (saveFitted == 1) {
-      SET_VECTOR_ELT(resultName_r, 1, mkChar("y.rep.samples")); 
-      SET_VECTOR_ELT(resultName_r, 2, mkChar("mu.samples"));
-      SET_VECTOR_ELT(resultName_r, 3, mkChar("like.samples"));
+      SET_VECTOR_ELT(resultName_r, 1, Rf_mkChar("y.rep.samples"));
+      SET_VECTOR_ELT(resultName_r, 2, Rf_mkChar("mu.samples"));
+      SET_VECTOR_ELT(resultName_r, 3, Rf_mkChar("like.samples"));
     }
     if (pAbundRE > 0) {
-      SET_VECTOR_ELT(resultName_r, 4, mkChar("sigma.sq.mu.samples")); 
-      SET_VECTOR_ELT(resultName_r, 5, mkChar("beta.star.samples")); 
+      SET_VECTOR_ELT(resultName_r, 4, Rf_mkChar("sigma.sq.mu.samples"));
+      SET_VECTOR_ELT(resultName_r, 5, Rf_mkChar("beta.star.samples"));
     }
     if (family == 1) {
-      SET_VECTOR_ELT(resultName_r, tmp_0, mkChar("kappa.samples")); 
+      SET_VECTOR_ELT(resultName_r, tmp_0, Rf_mkChar("kappa.samples"));
     }
-   
-    namesgets(result_r, resultName_r);
-    
+
+    Rf_namesgets(result_r, resultName_r);
+
     UNPROTECT(nProtect);
-    
+
     return(result_r);
   }
 }
