@@ -7,6 +7,7 @@
 #include <omp.h>
 #endif
 
+#define R_NO_REMAP
 #include <R.h>
 #include <Rmath.h>
 #include <Rinternals.h>
@@ -19,30 +20,30 @@
 
 extern "C" {
   SEXP msAbundGaussian(SEXP y_r, SEXP X_r, SEXP XRE_r,
-                       SEXP XRandom_r, SEXP consts_r, SEXP nRELong_r, 
-                       SEXP betaStarting_r, SEXP betaCommStarting_r,  
+                       SEXP XRandom_r, SEXP consts_r, SEXP nRELong_r,
+                       SEXP betaStarting_r, SEXP betaCommStarting_r,
                        SEXP tauSqBetaStarting_r, SEXP tauSqStarting_r,
-                       SEXP sigmaSqMuStarting_r, SEXP betaStarStarting_r, 
-		       SEXP betaStarIndx_r, SEXP betaLevelIndx_r, 
-                       SEXP muBetaComm_r, SEXP SigmaBetaComm_r, SEXP tauSqBetaA_r, 
+                       SEXP sigmaSqMuStarting_r, SEXP betaStarStarting_r,
+                       SEXP betaStarIndx_r, SEXP betaLevelIndx_r,
+                       SEXP muBetaComm_r, SEXP SigmaBetaComm_r, SEXP tauSqBetaA_r,
                        SEXP tauSqBetaB_r, SEXP tauSqA_r, SEXP tauSqB_r,
-		       SEXP sigmaSqMuA_r, SEXP sigmaSqMuB_r, 
-                       SEXP tuning_r, SEXP nBatch_r, SEXP batchLength_r, 
-                       SEXP acceptRate_r, SEXP nThreads_r, 
-                       SEXP verbose_r, SEXP nReport_r, 
+                       SEXP sigmaSqMuA_r, SEXP sigmaSqMuB_r,
+                       SEXP tuning_r, SEXP nBatch_r, SEXP batchLength_r,
+                       SEXP acceptRate_r, SEXP nThreads_r,
+                       SEXP verbose_r, SEXP nReport_r,
                        SEXP samplesInfo_r, SEXP chainInfo_r,
                        SEXP z_r, SEXP family_r){
-   
+
     /**********************************************************************
      * Initial constants
      * *******************************************************************/
-    // Indexing key (this is general, might deviate in a couple spots): 
-    // i = species 
+    // Indexing key (this is general, might deviate in a couple spots):
+    // i = species
     // j = site
     // ll = latent factor
     // h = coefficients
-    // rr = spatially-varying coefficient. 
-    int i, j, s, g, t, h, l, info, nProtect=0, ll;    
+    // rr = spatially-varying coefficient.
+    int i, j, s, g, t, h, l, info, nProtect=0, ll;
 
     const int inc = 1;
     const double one = 1.0;
@@ -50,50 +51,50 @@ extern "C" {
     char const *lower = "L";
     char const *ntran = "N";
     char const *ytran = "T";
-    
+
     /**********************************************************************
      * Get Inputs
      * *******************************************************************/
-    // Sorted by site, then by species. 
+    // Sorted by site, then by species.
     double *y = REAL(y_r);
     double *X = REAL(X_r);
     double *XRandom = REAL(XRandom_r);
     // Order: covariate, site
     int *XRE = INTEGER(XRE_r);
     // Load constants
-    int N = INTEGER(consts_r)[0]; 
+    int N = INTEGER(consts_r)[0];
     int J = INTEGER(consts_r)[1];
     int p = INTEGER(consts_r)[2];
     int pRE = INTEGER(consts_r)[3];
     int nRE = INTEGER(consts_r)[4];
     int saveFitted = INTEGER(consts_r)[5];
-    int pp = p * p; 
-    double *muBetaComm = REAL(muBetaComm_r); 
-    double *SigmaBetaCommInv = (double *) R_alloc(pp, sizeof(double));   
+    int pp = p * p;
+    double *muBetaComm = REAL(muBetaComm_r);
+    double *SigmaBetaCommInv = (double *) R_alloc(pp, sizeof(double));
     F77_NAME(dcopy)(&pp, REAL(SigmaBetaComm_r), &inc, SigmaBetaCommInv, &inc);
-    double *tauSqBetaA = REAL(tauSqBetaA_r); 
-    double *tauSqBetaB = REAL(tauSqBetaB_r); 
-    double *tauSqA = REAL(tauSqA_r); 
-    double *tauSqB = REAL(tauSqB_r); 
-    double *sigmaSqMuA = REAL(sigmaSqMuA_r); 
-    double *sigmaSqMuB = REAL(sigmaSqMuB_r); 
-    int *nRELong = INTEGER(nRELong_r); 
-    int *betaStarIndx = INTEGER(betaStarIndx_r); 
+    double *tauSqBetaA = REAL(tauSqBetaA_r);
+    double *tauSqBetaB = REAL(tauSqBetaB_r);
+    double *tauSqA = REAL(tauSqA_r);
+    double *tauSqB = REAL(tauSqB_r);
+    double *sigmaSqMuA = REAL(sigmaSqMuA_r);
+    double *sigmaSqMuB = REAL(sigmaSqMuB_r);
+    int *nRELong = INTEGER(nRELong_r);
+    int *betaStarIndx = INTEGER(betaStarIndx_r);
     int *betaLevelIndx = INTEGER(betaLevelIndx_r);
-    int nBatch = INTEGER(nBatch_r)[0]; 
-    int batchLength = INTEGER(batchLength_r)[0]; 
-    int nSamples = nBatch * batchLength; 
-    int nBurn = INTEGER(samplesInfo_r)[0]; 
+    int nBatch = INTEGER(nBatch_r)[0];
+    int batchLength = INTEGER(batchLength_r)[0];
+    int nSamples = nBatch * batchLength;
+    int nBurn = INTEGER(samplesInfo_r)[0];
     int nThin = INTEGER(samplesInfo_r)[1];
-    int nPost = INTEGER(samplesInfo_r)[2]; 
+    int nPost = INTEGER(samplesInfo_r)[2];
     int currChain = INTEGER(chainInfo_r)[0];
     int nChain = INTEGER(chainInfo_r)[1];
     int nThreads = INTEGER(nThreads_r)[0];
     int verbose = INTEGER(verbose_r)[0];
     int nReport = INTEGER(nReport_r)[0];
-    int status = 0; 
-    int thinIndx = 0; 
-    int sPost = 0; 
+    int status = 0;
+    int thinIndx = 0;
+    int sPost = 0;
     // First stage samples
     double *z = REAL(z_r);
     int family = INTEGER(family_r)[0];
@@ -102,13 +103,13 @@ extern "C" {
     omp_set_num_threads(nThreads);
 #else
     if(nThreads > 1){
-      warning("n.omp.threads > %i, but source not compiled with OpenMP support.", nThreads);
+      Rf_warning("n.omp.threads > %i, but source not compiled with OpenMP support.", nThreads);
       nThreads = 1;
     }
 #endif
-    
+
     /**********************************************************************
-     * Print Information 
+     * Print Information
      * *******************************************************************/
     if(verbose){
       if (currChain == 1) {
@@ -121,10 +122,10 @@ extern "C" {
           Rprintf("Multi-species Zero-Inflated Gaussian Model with %i sites and %i species.\n\n", J, N);
 	}
         Rprintf("Samples per chain: %i (%i batches of length %i)\n", nSamples, nBatch, batchLength);
-        Rprintf("Burn-in: %i \n", nBurn); 
-        Rprintf("Thinning Rate: %i \n", nThin); 
+        Rprintf("Burn-in: %i \n", nBurn);
+        Rprintf("Thinning Rate: %i \n", nThin);
         Rprintf("Number of Chains: %i \n", nChain);
-        Rprintf("Total Posterior Samples: %i \n\n", nPost * nChain); 
+        Rprintf("Total Posterior Samples: %i \n\n", nPost * nChain);
 #ifdef _OPENMP
         Rprintf("Source compiled with OpenMP support and model fit using %i thread(s).\n\n", nThreads);
 #else
@@ -140,20 +141,20 @@ extern "C" {
     /**********************************************************************
        Some constants and temporary variables to be used later
      * *******************************************************************/
-    int pN = p * N; 
-    int nREN = nRE * N; 
+    int pN = p * N;
+    int nREN = nRE * N;
     int JN = J * N;
-    int Jp = J * p; 
+    int Jp = J * p;
     int JpRE = J * p;
-    double tmp_0, tmp_02; 
-    double *tmp_one = (double *) R_alloc(inc, sizeof(double)); 
-    double *tmp_pp = (double *) R_alloc(pp, sizeof(double)); 
+    double tmp_0, tmp_02;
+    double *tmp_one = (double *) R_alloc(inc, sizeof(double));
+    double *tmp_pp = (double *) R_alloc(pp, sizeof(double));
     double *tmp_p = (double *) R_alloc(p, sizeof(double));
     double *tmp_beta = (double *) R_alloc(p, sizeof(double));
     double *tmp_p2 = (double *) R_alloc(p, sizeof(double));
     int *tmp_JInt = (int *) R_alloc(J, sizeof(int));
     for (j = 0; j < J; j++) {
-      tmp_JInt[j] = 0; 
+      tmp_JInt[j] = 0;
     }
     double *tmp_J = (double *) R_alloc(J, sizeof(double));
     zeros(tmp_J, J);
@@ -166,22 +167,22 @@ extern "C" {
      * Parameters
      * *******************************************************************/
     // Community level
-    double *betaComm = (double *) R_alloc(p, sizeof(double)); 
+    double *betaComm = (double *) R_alloc(p, sizeof(double));
     F77_NAME(dcopy)(&p, REAL(betaCommStarting_r), &inc, betaComm, &inc);
-    double *tauSqBeta = (double *) R_alloc(p, sizeof(double)); 
+    double *tauSqBeta = (double *) R_alloc(p, sizeof(double));
     F77_NAME(dcopy)(&p, REAL(tauSqBetaStarting_r), &inc, tauSqBeta, &inc);
     // Species level
-    double *beta = (double *) R_alloc(pN, sizeof(double));   
+    double *beta = (double *) R_alloc(pN, sizeof(double));
     F77_NAME(dcopy)(&pN, REAL(betaStarting_r), &inc, beta, &inc);
     // Nuggets
-    double *tauSq = (double *) R_alloc(N, sizeof(double)); 
+    double *tauSq = (double *) R_alloc(N, sizeof(double));
     F77_NAME(dcopy)(&N, REAL(tauSqStarting_r), &inc, tauSq, &inc);
     // Occurrence random effect variances
-    double *sigmaSqMu = (double *) R_alloc(pRE, sizeof(double)); 
-    F77_NAME(dcopy)(&pRE, REAL(sigmaSqMuStarting_r), &inc, sigmaSqMu, &inc); 
+    double *sigmaSqMu = (double *) R_alloc(pRE, sizeof(double));
+    F77_NAME(dcopy)(&pRE, REAL(sigmaSqMuStarting_r), &inc, sigmaSqMu, &inc);
     // Latent occurrence random effects
-    double *betaStar = (double *) R_alloc(nREN, sizeof(double)); 
-    F77_NAME(dcopy)(&nREN, REAL(betaStarStarting_r), &inc, betaStar, &inc); 
+    double *betaStar = (double *) R_alloc(nREN, sizeof(double));
+    F77_NAME(dcopy)(&nREN, REAL(betaStarStarting_r), &inc, betaStar, &inc);
     // Fitted vals
     double *yRep = (double *) R_alloc(JN, sizeof(double)); zeros(yRep, JN);
 
@@ -189,66 +190,66 @@ extern "C" {
      * Return Stuff
      * *******************************************************************/
     // Community level
-    SEXP betaCommSamples_r; 
-    PROTECT(betaCommSamples_r = allocMatrix(REALSXP, p, nPost)); nProtect++;
+    SEXP betaCommSamples_r;
+    PROTECT(betaCommSamples_r = Rf_allocMatrix(REALSXP, p, nPost)); nProtect++;
     zeros(REAL(betaCommSamples_r), p * nPost);
-    SEXP tauSqBetaSamples_r; 
-    PROTECT(tauSqBetaSamples_r = allocMatrix(REALSXP, p, nPost)); nProtect++; 
+    SEXP tauSqBetaSamples_r;
+    PROTECT(tauSqBetaSamples_r = Rf_allocMatrix(REALSXP, p, nPost)); nProtect++;
     zeros(REAL(tauSqBetaSamples_r), p * nPost);
     // Species level
     SEXP betaSamples_r;
-    PROTECT(betaSamples_r = allocMatrix(REALSXP, pN, nPost)); nProtect++;
+    PROTECT(betaSamples_r = Rf_allocMatrix(REALSXP, pN, nPost)); nProtect++;
     zeros(REAL(betaSamples_r), pN * nPost);
     SEXP tauSqSamples_r;
-    PROTECT(tauSqSamples_r = allocMatrix(REALSXP, N, nPost)); nProtect++;
+    PROTECT(tauSqSamples_r = Rf_allocMatrix(REALSXP, N, nPost)); nProtect++;
     zeros(REAL(tauSqSamples_r), N * nPost);
-    SEXP yRepSamples_r; 
-    SEXP muSamples_r; 
+    SEXP yRepSamples_r;
+    SEXP muSamples_r;
     SEXP likeSamples_r;
     if (saveFitted == 1) {
-      PROTECT(yRepSamples_r = allocMatrix(REALSXP, JN, nPost)); nProtect++; 
+      PROTECT(yRepSamples_r = Rf_allocMatrix(REALSXP, JN, nPost)); nProtect++;
       zeros(REAL(yRepSamples_r), JN * nPost);
-      PROTECT(muSamples_r = allocMatrix(REALSXP, JN, nPost)); nProtect++; 
+      PROTECT(muSamples_r = Rf_allocMatrix(REALSXP, JN, nPost)); nProtect++;
       zeros(REAL(muSamples_r), JN * nPost);
-      PROTECT(likeSamples_r = allocMatrix(REALSXP, JN, nPost)); nProtect++;
+      PROTECT(likeSamples_r = Rf_allocMatrix(REALSXP, JN, nPost)); nProtect++;
       zeros(REAL(likeSamples_r), JN * nPost);
     }
     // Random effects
-    SEXP sigmaSqMuSamples_r; 
-    SEXP betaStarSamples_r; 
+    SEXP sigmaSqMuSamples_r;
+    SEXP betaStarSamples_r;
     if (pRE > 0) {
-      PROTECT(sigmaSqMuSamples_r = allocMatrix(REALSXP, pRE, nPost)); nProtect++;
+      PROTECT(sigmaSqMuSamples_r = Rf_allocMatrix(REALSXP, pRE, nPost)); nProtect++;
       zeros(REAL(sigmaSqMuSamples_r), pRE * nPost);
-      PROTECT(betaStarSamples_r = allocMatrix(REALSXP, nREN, nPost)); nProtect++;
+      PROTECT(betaStarSamples_r = Rf_allocMatrix(REALSXP, nREN, nPost)); nProtect++;
       zeros(REAL(betaStarSamples_r), nREN * nPost);
     }
-    // Likelihood samples for WAIC. 
-    
+    // Likelihood samples for WAIC.
+
     /**********************************************************************
      * Additional Sampler Prep
      * *******************************************************************/
-    double *mu = (double *) R_alloc(JN, sizeof(double)); 
-    zeros(mu, JN); 
-    double *like = (double *) R_alloc(JN, sizeof(double)); zeros(like, JN); 
+    double *mu = (double *) R_alloc(JN, sizeof(double));
+    zeros(mu, JN);
+    double *like = (double *) R_alloc(JN, sizeof(double)); zeros(like, JN);
 
     // For normal community-level priors
     // Occurrence coefficients
-    F77_NAME(dpotrf)(lower, &p, SigmaBetaCommInv, &p, &info FCONE); 
-    if(info != 0){error("c++ error: dpotrf SigmaBetaCommInv failed\n");}
-    F77_NAME(dpotri)(lower, &p, SigmaBetaCommInv, &p, &info FCONE); 
-    if(info != 0){error("c++ error: dpotri SigmaBetaCommInv failed\n");}
-    double *SigmaBetaCommInvMuBeta = (double *) R_alloc(p, sizeof(double)); 
-    F77_NAME(dsymv)(lower, &p, &one, SigmaBetaCommInv, &p, muBetaComm, &inc, &zero, 
+    F77_NAME(dpotrf)(lower, &p, SigmaBetaCommInv, &p, &info FCONE);
+    if(info != 0){Rf_error("c++ error: dpotrf SigmaBetaCommInv failed\n");}
+    F77_NAME(dpotri)(lower, &p, SigmaBetaCommInv, &p, &info FCONE);
+    if(info != 0){Rf_error("c++ error: dpotri SigmaBetaCommInv failed\n");}
+    double *SigmaBetaCommInvMuBeta = (double *) R_alloc(p, sizeof(double));
+    F77_NAME(dsymv)(lower, &p, &one, SigmaBetaCommInv, &p, muBetaComm, &inc, &zero,
         	    SigmaBetaCommInvMuBeta, &inc FCONE);
     // Put community level occurrence variances in a p x p matrix.
-    double *TauBetaInv = (double *) R_alloc(pp, sizeof(double)); zeros(TauBetaInv, pp); 
+    double *TauBetaInv = (double *) R_alloc(pp, sizeof(double)); zeros(TauBetaInv, pp);
     for (i = 0; i < p; i++) {
-      TauBetaInv[i * p + i] = tauSqBeta[i]; 
+      TauBetaInv[i * p + i] = tauSqBeta[i];
     } // i
-    F77_NAME(dpotrf)(lower, &p, TauBetaInv, &p, &info FCONE); 
-    if(info != 0){error("c++ error: dpotrf TauBetaInv failed\n");}
-    F77_NAME(dpotri)(lower, &p, TauBetaInv, &p, &info FCONE); 
-    if(info != 0){error("c++ error: dpotri TauBetaInv failed\n");}
+    F77_NAME(dpotrf)(lower, &p, TauBetaInv, &p, &info FCONE);
+    if(info != 0){Rf_error("c++ error: dpotrf TauBetaInv failed\n");}
+    F77_NAME(dpotri)(lower, &p, TauBetaInv, &p, &info FCONE);
+    if(info != 0){Rf_error("c++ error: dpotri TauBetaInv failed\n");}
     // For current number of nonzero z values
     double *currJ = (double *) R_alloc(N, sizeof(double)); zeros(currJ, N);
     for (i = 0; i < N; i++) {
@@ -261,8 +262,8 @@ extern "C" {
      * Prep for random effects (if they exist)
      * *******************************************************************/
     // Site-level sums of the occurrence random effects
-    double *betaStarSites = (double *) R_alloc(JN, sizeof(double)); 
-    zeros(betaStarSites, JN); 
+    double *betaStarSites = (double *) R_alloc(JN, sizeof(double));
+    zeros(betaStarSites, JN);
     int *betaStarLongIndx = (int *) R_alloc(JpRE, sizeof(int));
     // Initial sums (initiate with the first species)
     for (j = 0; j < J; j++) {
@@ -275,9 +276,9 @@ extern "C" {
     }
 
     // Starting index for occurrence random effects
-    int *betaStarStart = (int *) R_alloc(pRE, sizeof(int)); 
+    int *betaStarStart = (int *) R_alloc(pRE, sizeof(int));
     for (l = 0; l < pRE; l++) {
-      betaStarStart[l] = which(l, betaStarIndx, nRE); 
+      betaStarStart[l] = which(l, betaStarIndx, nRE);
     }
 
     GetRNGstate();
@@ -294,65 +295,65 @@ extern "C" {
         /********************************
          Compute b.beta.comm
          *******************************/
-        zeros(tmp_p, p); 
+        zeros(tmp_p, p);
         for (i = 0; i < N; i++) {
-          F77_NAME(dgemv)(ytran, &p, &p, &one, TauBetaInv, &p, &beta[i], &N, &one, tmp_p, &inc FCONE); 
+          F77_NAME(dgemv)(ytran, &p, &p, &one, TauBetaInv, &p, &beta[i], &N, &one, tmp_p, &inc FCONE);
         } // i
         for (h = 0; h < p; h++) {
-          tmp_p[h] += SigmaBetaCommInvMuBeta[h];  
+          tmp_p[h] += SigmaBetaCommInvMuBeta[h];
         } // j
 
         /********************************
          Compute A.beta.comm
          *******************************/
         for (h = 0; h < pp; h++) {
-          tmp_pp[h] = SigmaBetaCommInv[h] + N * TauBetaInv[h]; 
+          tmp_pp[h] = SigmaBetaCommInv[h] + N * TauBetaInv[h];
         }
-        F77_NAME(dpotrf)(lower, &p, tmp_pp, &p, &info FCONE); 
-        if(info != 0){error("c++ error: dpotrf ABetaComm failed\n");}
-        F77_NAME(dpotri)(lower, &p, tmp_pp, &p, &info FCONE); 
-        if(info != 0){error("c++ error: dpotri ABetaComm failed\n");}
+        F77_NAME(dpotrf)(lower, &p, tmp_pp, &p, &info FCONE);
+        if(info != 0){Rf_error("c++ error: dpotrf ABetaComm failed\n");}
+        F77_NAME(dpotri)(lower, &p, tmp_pp, &p, &info FCONE);
+        if(info != 0){Rf_error("c++ error: dpotri ABetaComm failed\n");}
         // A.beta.inv %*% b.beta
         // 1 * tmp_pp * tmp_p + 0 * tmp_p2  = tmp_p2
         F77_NAME(dsymv)(lower, &p, &one, tmp_pp, &p, tmp_p, &inc, &zero, tmp_p2, &inc FCONE);
         // Computes cholesky of tmp_pp again stored back in tmp_pp. This chol(A.beta.inv)
-        F77_NAME(dpotrf)(lower, &p, tmp_pp, &p, &info FCONE); 
-        if(info != 0){error("c++ error: dpotrf ABetaComm failed\n");}
+        F77_NAME(dpotrf)(lower, &p, tmp_pp, &p, &info FCONE);
+        if(info != 0){Rf_error("c++ error: dpotrf ABetaComm failed\n");}
         // Args: destination, mu, cholesky of the inverse covariance matrix, dimension
         mvrnorm(betaComm, tmp_p2, tmp_pp, p);
         /********************************************************************
          Update Community Occupancy Variance Parameter
         ********************************************************************/
         for (h = 0; h < p; h++) {
-          tmp_0 = 0.0;  
+          tmp_0 = 0.0;
           for (i = 0; i < N; i++) {
             tmp_0 += (beta[h * N + i] - betaComm[h]) * (beta[h * N + i] - betaComm[h]);
           } // i
           tmp_0 *= 0.5;
-          tauSqBeta[h] = rigamma(tauSqBetaA[h] + N / 2.0, tauSqBetaB[h] + tmp_0); 
+          tauSqBeta[h] = rigamma(tauSqBetaA[h] + N / 2.0, tauSqBetaB[h] + tmp_0);
         } // h
         for (h = 0; h < p; h++) {
-          TauBetaInv[h * p + h] = tauSqBeta[h]; 
+          TauBetaInv[h * p + h] = tauSqBeta[h];
         } // i
-        F77_NAME(dpotrf)(lower, &p, TauBetaInv, &p, &info FCONE); 
-        if(info != 0){error("c++ error: dpotrf TauBetaInv failed\n");}
-        F77_NAME(dpotri)(lower, &p, TauBetaInv, &p, &info FCONE); 
-        if(info != 0){error("c++ error: dpotri TauBetaInv failed\n");}
+        F77_NAME(dpotrf)(lower, &p, TauBetaInv, &p, &info FCONE);
+        if(info != 0){Rf_error("c++ error: dpotrf TauBetaInv failed\n");}
+        F77_NAME(dpotri)(lower, &p, TauBetaInv, &p, &info FCONE);
+        if(info != 0){Rf_error("c++ error: dpotri TauBetaInv failed\n");}
         /********************************************************************
          *Update Occupancy random effects variance
          *******************************************************************/
         for (l = 0; l < pRE; l++) {
-          tmp_0 = 0.0; 
+          tmp_0 = 0.0;
           for (i = 0; i < N; i++) {
-            tmp_0 += F77_NAME(ddot)(&nRELong[l], &betaStar[i*nRE + betaStarStart[l]], &inc, &betaStar[i*nRE + betaStarStart[l]], &inc); 
+            tmp_0 += F77_NAME(ddot)(&nRELong[l], &betaStar[i*nRE + betaStarStart[l]], &inc, &betaStar[i*nRE + betaStarStart[l]], &inc);
           }
-          tmp_0 *= 0.5; 
+          tmp_0 *= 0.5;
           sigmaSqMu[l] = rigamma(sigmaSqMuA[l] + nRELong[l] * N / 2.0, sigmaSqMuB[l] + tmp_0);
         }
         /********************************************************************
          *Update Species-Specific Regression Parameters
          *******************************************************************/
-        for (i = 0; i < N; i++) {  
+        for (i = 0; i < N; i++) {
           /********************************************************************
            *Update Occupancy Regression Coefficients
            *******************************************************************/
@@ -365,10 +366,10 @@ extern "C" {
           /********************************
            * Compute b.beta
            *******************************/
-          // t(X) * tmp_J1 + 0 * tmp_p = tmp_p. 
-          F77_NAME(dgemv)(ytran, &J, &p, &one, X, &J, tmp_J1, &inc, &zero, tmp_p, &inc FCONE); 	 
+          // t(X) * tmp_J1 + 0 * tmp_p = tmp_p.
+          F77_NAME(dgemv)(ytran, &J, &p, &one, X, &J, tmp_J1, &inc, &zero, tmp_p, &inc FCONE);
           // TauBetaInv %*% betaComm + tmp_p = tmp_p
-          F77_NAME(dgemv)(ntran, &p, &p, &one, TauBetaInv, &p, betaComm, &inc, &one, tmp_p, &inc FCONE); 
+          F77_NAME(dgemv)(ntran, &p, &p, &one, TauBetaInv, &p, betaComm, &inc, &one, tmp_p, &inc FCONE);
 
           /********************************
            * Compute A.beta
@@ -386,21 +387,21 @@ extern "C" {
           // 1 * X * tmp_Jp + 0 * tmp_pp = tmp_pp
           F77_NAME(dgemm)(ytran, ntran, &p, &p, &J, &one, X, &J, tmp_Jp, &J, &zero, tmp_pp, &p FCONE FCONE);
           for (h = 0; h < pp; h++) {
-            tmp_pp[h] += TauBetaInv[h]; 
+            tmp_pp[h] += TauBetaInv[h];
           } // j
-          F77_NAME(dpotrf)(lower, &p, tmp_pp, &p, &info FCONE); 
-          if(info != 0){error("c++ error: dpotrf ABeta failed\n");}
-          F77_NAME(dpotri)(lower, &p, tmp_pp, &p, &info FCONE); 
-          if(info != 0){error("c++ error: dpotri ABeta failed\n");}
+          F77_NAME(dpotrf)(lower, &p, tmp_pp, &p, &info FCONE);
+          if(info != 0){Rf_error("c++ error: dpotrf ABeta failed\n");}
+          F77_NAME(dpotri)(lower, &p, tmp_pp, &p, &info FCONE);
+          if(info != 0){Rf_error("c++ error: dpotri ABeta failed\n");}
           // A.beta.inv %*% b.beta
           F77_NAME(dsymv)(lower, &p, &one, tmp_pp, &p, tmp_p, &inc, &zero, tmp_p2, &inc FCONE);
-          F77_NAME(dpotrf)(lower, &p, tmp_pp, &p, &info FCONE); 
-	  if(info != 0){error("c++ error: dpotrf A.beta 2 failed\n");}
+          F77_NAME(dpotrf)(lower, &p, tmp_pp, &p, &info FCONE);
+	  if(info != 0){Rf_error("c++ error: dpotrf A.beta 2 failed\n");}
           // Args: destination, mu, cholesky of the covariance matrix, dimension
           mvrnorm(tmp_beta, tmp_p2, tmp_pp, p);
-          // Can eventually get rid of this and change order of beta. 
+          // Can eventually get rid of this and change order of beta.
           for (h = 0; h < p; h++) {
-            beta[h * N + i] = tmp_beta[h]; 
+            beta[h * N + i] = tmp_beta[h];
           }
           /********************************************************************
            *Update tau.sq
@@ -408,12 +409,12 @@ extern "C" {
 	   zeros(tmp_J1, J);
            for(j = 0; j < J; j++){
              if (z[j * N + i] == 1.0) {
-	       tmp_J1[j] = y[j * N + i] - 
-	         	  F77_NAME(ddot)(&p, &X[j], &J, &beta[i], &N) - 
+	       tmp_J1[j] = y[j * N + i] -
+	         	  F77_NAME(ddot)(&p, &X[j], &J, &beta[i], &N) -
 	         	  betaStarSites[i * J + j];
 	     }
            }
-           tauSq[i] = rigamma(tauSqA[i] + currJ[i] / 2.0, tauSqB[i] + 0.5 * 
+           tauSq[i] = rigamma(tauSqA[i] + currJ[i] / 2.0, tauSqB[i] + 0.5 *
                               F77_NAME(ddot)(&J, tmp_J1, &inc, tmp_J1, &inc));
           /********************************************************************
            *Update Occupancy random effects
@@ -421,16 +422,16 @@ extern "C" {
 	  if (pRE > 0) {
             // Reset betaStar to 0 since some levels may not be sampled for a given species
 	    // zeros(betaStar, nREN);
-            // Update each individual random effect one by one. 
+            // Update each individual random effect one by one.
             for (l = 0; l < nRE; l++) {
               /********************************
                * Compute b.beta.star
                *******************************/
               zeros(tmp_one, inc);
-              tmp_0 = 0.0;	      
-	      // Only allow information to come from when XRE == betaLevelIndx[l]. 
-	      // aka information only comes from the sites with any given level 
-	      // of a random effect. 
+              tmp_0 = 0.0;
+	      // Only allow information to come from when XRE == betaLevelIndx[l].
+	      // aka information only comes from the sites with any given level
+	      // of a random effect.
               for (j = 0; j < J; j++) {
                 if ((z[j * N + i] == 1.0) && (XRE[betaStarIndx[l] * J + j] == betaLevelIndx[l])) {
                   tmp_02 = 0.0;
@@ -444,9 +445,9 @@ extern "C" {
               /********************************
                * Compute A.beta.star
                *******************************/
-              tmp_0 += 1.0 / sigmaSqMu[betaStarIndx[l]]; 
-              tmp_0 = 1.0 / tmp_0; 
-              betaStar[i * nRE + l] = rnorm(tmp_0 * tmp_one[0], sqrt(tmp_0)); 
+              tmp_0 += 1.0 / sigmaSqMu[betaStarIndx[l]];
+              tmp_0 = 1.0 / tmp_0;
+              betaStar[i * nRE + l] = rnorm(tmp_0 * tmp_one[0], sqrt(tmp_0));
             }
 
             // Update the RE sums for the current species
@@ -489,25 +490,25 @@ extern "C" {
             F77_NAME(dcopy)(&p, betaComm, &inc, &REAL(betaCommSamples_r)[sPost*p], &inc);
             F77_NAME(dcopy)(&p, tauSqBeta, &inc, &REAL(tauSqBetaSamples_r)[sPost*p], &inc);
             F77_NAME(dcopy)(&N, tauSq, &inc, &REAL(tauSqSamples_r)[sPost*N], &inc);
-            F77_NAME(dcopy)(&pN, beta, &inc, &REAL(betaSamples_r)[sPost*pN], &inc); 
+            F77_NAME(dcopy)(&pN, beta, &inc, &REAL(betaSamples_r)[sPost*pN], &inc);
 	    if (saveFitted == 1) {
-              F77_NAME(dcopy)(&JN, mu, &inc, &REAL(muSamples_r)[sPost*JN], &inc); 
-              F77_NAME(dcopy)(&JN, yRep, &inc, &REAL(yRepSamples_r)[sPost*JN], &inc); 
-              F77_NAME(dcopy)(&JN, like, &inc, &REAL(likeSamples_r)[sPost*JN], &inc); 
+              F77_NAME(dcopy)(&JN, mu, &inc, &REAL(muSamples_r)[sPost*JN], &inc);
+              F77_NAME(dcopy)(&JN, yRep, &inc, &REAL(yRepSamples_r)[sPost*JN], &inc);
+              F77_NAME(dcopy)(&JN, like, &inc, &REAL(likeSamples_r)[sPost*JN], &inc);
 	    }
 	    if (pRE > 0) {
               F77_NAME(dcopy)(&pRE, sigmaSqMu, &inc, &REAL(sigmaSqMuSamples_r)[sPost*pRE], &inc);
               F77_NAME(dcopy)(&nREN, betaStar, &inc, &REAL(betaStarSamples_r)[sPost*nREN], &inc);
 	    }
-            sPost++; 
-            thinIndx = 0; 
+            sPost++;
+            thinIndx = 0;
           }
         }
         R_CheckUserInterrupt();
       } // t (end batch)
 
       /********************************************************************
-       *Report 
+       *Report
        *******************************************************************/
       if (verbose) {
 	if (status == nReport) {
@@ -519,14 +520,14 @@ extern "C" {
 	  status = 0;
 	}
       }
-      status++;        
+      status++;
 
     } // all batches
     if (verbose) {
       Rprintf("Batch: %i of %i, %3.2f%%\n", s, nBatch, 100.0*s/nBatch);
     }
-  
-    // This is necessary when generating random numbers in C.     
+
+    // This is necessary when generating random numbers in C.
     PutRNGstate();
 
     // make return object (which is a list)
@@ -536,8 +537,8 @@ extern "C" {
       nResultListObjs += 2;
     }
 
-    PROTECT(result_r = allocVector(VECSXP, nResultListObjs)); nProtect++;
-    PROTECT(resultName_r = allocVector(VECSXP, nResultListObjs)); nProtect++;
+    PROTECT(result_r = Rf_allocVector(VECSXP, nResultListObjs)); nProtect++;
+    PROTECT(resultName_r = Rf_allocVector(VECSXP, nResultListObjs)); nProtect++;
 
     // Setting the components of the output list.
     SET_VECTOR_ELT(result_r, 0, betaCommSamples_r);
@@ -546,35 +547,35 @@ extern "C" {
     if (saveFitted == 1) {
       SET_VECTOR_ELT(result_r, 3, yRepSamples_r);
       SET_VECTOR_ELT(result_r, 4, muSamples_r);
-      SET_VECTOR_ELT(result_r, 6, likeSamples_r); 
+      SET_VECTOR_ELT(result_r, 6, likeSamples_r);
     }
-    SET_VECTOR_ELT(result_r, 5, tauSqSamples_r); 
+    SET_VECTOR_ELT(result_r, 5, tauSqSamples_r);
     if (pRE > 0) {
       SET_VECTOR_ELT(result_r, 7, sigmaSqMuSamples_r);
       SET_VECTOR_ELT(result_r, 8, betaStarSamples_r);
     }
 
-    // mkChar turns a C string into a CHARSXP
-    SET_VECTOR_ELT(resultName_r, 0, mkChar("beta.comm.samples")); 
-    SET_VECTOR_ELT(resultName_r, 1, mkChar("tau.sq.beta.samples")); 
-    SET_VECTOR_ELT(resultName_r, 2, mkChar("beta.samples")); 
+    // Rf_mkChar turns a C string into a CHARSXP
+    SET_VECTOR_ELT(resultName_r, 0, Rf_mkChar("beta.comm.samples"));
+    SET_VECTOR_ELT(resultName_r, 1, Rf_mkChar("tau.sq.beta.samples"));
+    SET_VECTOR_ELT(resultName_r, 2, Rf_mkChar("beta.samples"));
     if (saveFitted == 1) {
-      SET_VECTOR_ELT(resultName_r, 3, mkChar("y.rep.samples")); 
-      SET_VECTOR_ELT(resultName_r, 4, mkChar("mu.samples")); 
-      SET_VECTOR_ELT(resultName_r, 6, mkChar("like.samples")); 
+      SET_VECTOR_ELT(resultName_r, 3, Rf_mkChar("y.rep.samples"));
+      SET_VECTOR_ELT(resultName_r, 4, Rf_mkChar("mu.samples"));
+      SET_VECTOR_ELT(resultName_r, 6, Rf_mkChar("like.samples"));
     }
-    SET_VECTOR_ELT(resultName_r, 5, mkChar("tau.sq.samples")); 
+    SET_VECTOR_ELT(resultName_r, 5, Rf_mkChar("tau.sq.samples"));
     if (pRE > 0) {
-      SET_VECTOR_ELT(resultName_r, 7, mkChar("sigma.sq.mu.samples")); 
-      SET_VECTOR_ELT(resultName_r, 8, mkChar("beta.star.samples")); 
+      SET_VECTOR_ELT(resultName_r, 7, Rf_mkChar("sigma.sq.mu.samples"));
+      SET_VECTOR_ELT(resultName_r, 8, Rf_mkChar("beta.star.samples"));
     }
-   
-    // Set the names of the output list.  
-    namesgets(result_r, resultName_r);
-    
+
+    // Set the names of the output list.
+    Rf_namesgets(result_r, resultName_r);
+
     //unprotect
     UNPROTECT(nProtect);
-    
+
     return(result_r);
   }
 }
